# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_chat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.steammessages_clientserver_friends_pb2 as steammessages__clientserver__friends__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18steammessages_chat.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a(steammessages_clientserver_friends.proto\"*\n(CChat_RequestFriendPersonaStates_Request\"+\n)CChat_RequestFriendPersonaStates_Response\"\xce\x01\n%CChatRoom_CreateChatRoomGroup_Request\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\x12\x17\n\x0fsteamid_invited\x18\x02 \x01(\x06\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x18\n\x10steamid_invitees\x18\x04 \x03(\x06\x12$\n\x1cwatching_broadcast_accountid\x18\x06 \x01(\r\x12%\n\x1dwatching_broadcast_channel_id\x18\x07 \x01(\x04\";\n\tCChatRole\x12\x0f\n\x07role_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\"\xd4\x02\n\x10\x43\x43hatRoleActions\x12\x0f\n\x07role_id\x18\x01 \x01(\x04\x12(\n can_create_rename_delete_channel\x18\x02 \x01(\x08\x12\x10\n\x08\x63\x61n_kick\x18\x03 \x01(\x08\x12\x0f\n\x07\x63\x61n_ban\x18\x04 \x01(\x08\x12\x12\n\ncan_invite\x18\x05 \x01(\x08\x12&\n\x1e\x63\x61n_change_tagline_avatar_name\x18\x06 \x01(\x08\x12\x10\n\x08\x63\x61n_chat\x18\x07 \x01(\x08\x12\x18\n\x10\x63\x61n_view_history\x18\x08 \x01(\x08\x12\x1e\n\x16\x63\x61n_change_group_roles\x18\t \x01(\x08\x12\x1d\n\x15\x63\x61n_change_user_roles\x18\n \x01(\x08\x12\x17\n\x0f\x63\x61n_mention_all\x18\x0b \x01(\x08\x12\"\n\x1a\x63\x61n_set_watching_broadcast\x18\x0c \x01(\x08\"c\n\x10\x43\x43hatPartyBeacon\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x15\n\rsteamid_owner\x18\x02 \x01(\x06\x12\x11\n\tbeacon_id\x18\x03 \x01(\x06\x12\x15\n\rgame_metadata\x18\x04 \x01(\t\"\xbc\x03\n\x19\x43\x43hatRoomGroupHeaderState\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x11\n\tchat_name\x18\x02 \x01(\t\x12\x0e\n\x06\x63lanid\x18\r \x01(\r\x12\x17\n\x0f\x61\x63\x63ountid_owner\x18\x0e \x01(\r\x12\r\n\x05\x61ppid\x18\x15 \x01(\r\x12\x0f\n\x07tagline\x18\x0f \x01(\t\x12\x12\n\navatar_sha\x18\x10 \x01(\x0c\x12\x17\n\x0f\x64\x65\x66\x61ult_role_id\x18\x11 \x01(\x04\x12\x19\n\x05roles\x18\x12 \x03(\x0b\x32\n.CChatRole\x12\'\n\x0crole_actions\x18\x13 \x03(\x0b\x32\x11.CChatRoleActions\x12$\n\x1cwatching_broadcast_accountid\x18\x14 \x01(\r\x12(\n\rparty_beacons\x18\x16 \x03(\x0b\x32\x11.CChatPartyBeacon\x12%\n\x1dwatching_broadcast_channel_id\x18\x17 \x01(\x04\x12\x1a\n\x12\x61\x63tive_minigame_id\x18\x18 \x01(\x04\x12\x16\n\x0e\x61vatar_ugc_url\x18\x19 \x01(\t\x12\x10\n\x08\x64isabled\x18\x1a \x01(\x08\"\xd3\x01\n\x0f\x43\x43hatRoomMember\x12\x11\n\taccountid\x18\x01 \x01(\r\x12@\n\x05state\x18\x03 \x01(\x0e\x32\x13.EChatRoomJoinState:\x1ck_EChatRoomJoinState_Default\x12?\n\x04rank\x18\x04 \x01(\x0e\x32\x13.EChatRoomGroupRank:\x1ck_EChatRoomGroupRank_Default\x12\x18\n\x10time_kick_expire\x18\x06 \x01(\r\x12\x10\n\x08role_ids\x18\x07 \x03(\x04\"\xca\x01\n\x0e\x43\x43hatRoomState\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x04\x12\x11\n\tchat_name\x18\x02 \x01(\t\x12\x15\n\rvoice_allowed\x18\x03 \x01(\x08\x12\x18\n\x10members_in_voice\x18\x04 \x03(\r\x12\x19\n\x11time_last_message\x18\x05 \x01(\r\x12\x12\n\nsort_order\x18\x06 \x01(\r\x12\x14\n\x0clast_message\x18\x07 \x01(\t\x12\x1e\n\x16\x61\x63\x63ountid_last_message\x18\x08 \x01(\r\"\xca\x01\n\x13\x43\x43hatRoomGroupState\x12\x30\n\x0cheader_state\x18\x01 \x01(\x0b\x32\x1a.CChatRoomGroupHeaderState\x12!\n\x07members\x18\x02 \x03(\x0b\x32\x10.CChatRoomMember\x12\x17\n\x0f\x64\x65\x66\x61ult_chat_id\x18\x04 \x01(\x04\x12#\n\nchat_rooms\x18\x05 \x03(\x0b\x32\x0f.CChatRoomState\x12 \n\x06kicked\x18\x07 \x03(\x0b\x32\x10.CChatRoomMember\"\xfb\x02\n\x12\x43UserChatRoomState\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x04\x12\x13\n\x0btime_joined\x18\x02 \x01(\r\x12\x15\n\rtime_last_ack\x18\x03 \x01(\r\x12\x65\n\x1a\x64\x65sktop_notification_level\x18\x04 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x64\n\x19mobile_notification_level\x18\x05 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x19\n\x11time_last_mention\x18\x06 \x01(\r\x12%\n\x16unread_indicator_muted\x18\x07 \x01(\x08:\x05\x66\x61lse\x12\x19\n\x11time_first_unread\x18\x08 \x01(\r\"\x89\x03\n\x17\x43UserChatRoomGroupState\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x13\n\x0btime_joined\x18\x02 \x01(\r\x12\x31\n\x14user_chat_room_state\x18\x03 \x03(\x0b\x32\x13.CUserChatRoomState\x12\x65\n\x1a\x64\x65sktop_notification_level\x18\x04 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x64\n\x19mobile_notification_level\x18\x05 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x1b\n\x13time_last_group_ack\x18\x06 \x01(\r\x12%\n\x16unread_indicator_muted\x18\x07 \x01(\x08:\x05\x66\x61lse\"\x97\x01\n&CChatRoom_CreateChatRoomGroup_Response\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12#\n\x05state\x18\x02 \x01(\x0b\x32\x14.CChatRoomGroupState\x12\x31\n\x0fuser_chat_state\x18\x03 \x01(\x0b\x32\x18.CUserChatRoomGroupState\"J\n#CChatRoom_SaveChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\"&\n$CChatRoom_SaveChatRoomGroup_Response\"L\n%CChatRoom_RenameChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\"6\n&CChatRoom_RenameChatRoomGroup_Response\x12\x0c\n\x04name\x18\x01 \x01(\t\"S\n)CChatRoom_SetChatRoomGroupTagline_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07tagline\x18\x02 \x01(\t\",\n*CChatRoom_SetChatRoomGroupTagline_Response\"U\n(CChatRoom_SetChatRoomGroupAvatar_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x12\n\navatar_sha\x18\x02 \x01(\x0c\"+\n)CChatRoom_SetChatRoomGroupAvatar_Response\"\x99\x01\n3CChatRoom_SetChatRoomGroupWatchingBroadcast_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12$\n\x1cwatching_broadcast_accountid\x18\x02 \x01(\r\x12%\n\x1dwatching_broadcast_channel_id\x18\x03 \x01(\x04\"6\n4CChatRoom_SetChatRoomGroupWatchingBroadcast_Response\"X\n.CChatRoom_JoinMiniGameForChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\"F\n/CChatRoom_JoinMiniGameForChatRoomGroup_Response\x12\x13\n\x0bminigame_id\x18\x01 \x01(\x04\"l\n-CChatRoom_EndMiniGameForChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x13\n\x0bminigame_id\x18\x03 \x01(\x04\"0\n.CChatRoom_EndMiniGameForChatRoomGroup_Response\"X\n\x1a\x43\x43hatRoom_MuteUser_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x12\n\nexpiration\x18\x03 \x01(\x05\"\x1d\n\x1b\x43\x43hatRoom_MuteUser_Response\"X\n\x1a\x43\x43hatRoom_KickUser_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x12\n\nexpiration\x18\x03 \x01(\x05\"\x1d\n\x1b\x43\x43hatRoom_KickUser_Response\"^\n!CChatRoom_SetUserBanState_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x11\n\tban_state\x18\x03 \x01(\x08\"$\n\"CChatRoom_SetUserBanState_Response\"H\n\x1e\x43\x43hatRoom_RevokeInvite_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"!\n\x1f\x43\x43hatRoom_RevokeInvite_Response\"C\n\x1c\x43\x43hatRoom_CreateRole_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\"C\n\x1d\x43\x43hatRoom_CreateRole_Response\x12\"\n\x07\x61\x63tions\x18\x02 \x01(\x0b\x32\x11.CChatRoleActions\"3\n\x1a\x43\x43hatRoom_GetRoles_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"8\n\x1b\x43\x43hatRoom_GetRoles_Response\x12\x19\n\x05roles\x18\x01 \x03(\x0b\x32\n.CChatRole\"T\n\x1c\x43\x43hatRoom_RenameRole_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x1f\n\x1d\x43\x43hatRoom_RenameRole_Response\"X\n\x1d\x43\x43hatRoom_ReorderRole_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x02 \x01(\x04\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\" \n\x1e\x43\x43hatRoom_ReorderRole_Response\"F\n\x1c\x43\x43hatRoom_DeleteRole_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x02 \x01(\x04\"\x1f\n\x1d\x43\x43hatRoom_DeleteRole_Response\"J\n CChatRoom_GetRoleActions_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x02 \x01(\x04\"G\n!CChatRoom_GetRoleActions_Response\x12\"\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x11.CChatRoleActions\"r\n$CChatRoom_ReplaceRoleActions_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x02 \x01(\x04\x12\"\n\x07\x61\x63tions\x18\x04 \x01(\x0b\x32\x11.CChatRoleActions\"\'\n%CChatRoom_ReplaceRoleActions_Response\"Z\n\x1f\x43\x43hatRoom_AddRoleToUser_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x03 \x01(\x04\x12\x0f\n\x07steamid\x18\x04 \x01(\x06\"\"\n CChatRoom_AddRoleToUser_Response\"K\n!CChatRoom_GetRolesForUser_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\"6\n\"CChatRoom_GetRolesForUser_Response\x12\x10\n\x08role_ids\x18\x01 \x03(\x04\"_\n$CChatRoom_DeleteRoleFromUser_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07role_id\x18\x03 \x01(\x04\x12\x0f\n\x07steamid\x18\x04 \x01(\x06\"\'\n%CChatRoom_DeleteRoleFromUser_Response\"b\n#CChatRoom_JoinChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x13\n\x0binvite_code\x18\x02 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\x04\"\xa9\x01\n$CChatRoom_JoinChatRoomGroup_Response\x12#\n\x05state\x18\x01 \x01(\x0b\x32\x14.CChatRoomGroupState\x12\x31\n\x0fuser_chat_state\x18\x03 \x01(\x0b\x32\x18.CUserChatRoomGroupState\x12\x14\n\x0cjoin_chat_id\x18\x04 \x01(\x04\x12\x13\n\x0btime_expire\x18\x05 \x01(\r\"\x86\x01\n-CChatRoom_InviteFriendToChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\x04\x12\x1c\n\x14skip_friendsui_check\x18\x04 \x01(\x08\"0\n.CChatRoom_InviteFriendToChatRoomGroup_Response\"=\n$CChatRoom_LeaveChatRoomGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"\'\n%CChatRoom_LeaveChatRoomGroup_Response\"\\\n CChatRoom_CreateChatRoom_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x61llow_voice\x18\x03 \x01(\x08\"G\n!CChatRoom_CreateChatRoom_Response\x12\"\n\tchat_room\x18\x01 \x01(\x0b\x32\x0f.CChatRoomState\"J\n CChatRoom_DeleteChatRoom_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\"#\n!CChatRoom_DeleteChatRoom_Response\"X\n CChatRoom_RenameChatRoom_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\"#\n!CChatRoom_RenameChatRoom_Response\"g\n!CChatRoom_ReorderChatRoom_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x1a\n\x12move_after_chat_id\x18\x03 \x01(\x04\"$\n\"CChatRoom_ReorderChatRoom_Response\"t\n!CChatRoom_SendChatMessage_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x16\n\x0e\x65\x63ho_to_sender\x18\x04 \x01(\x08\"\x8a\x01\n\"CChatRoom_SendChatMessage_Response\x12\x18\n\x10modified_message\x18\x01 \x01(\t\x12\x18\n\x10server_timestamp\x18\x02 \x01(\r\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\x12\x1f\n\x17message_without_bb_code\x18\x04 \x01(\t\"I\n\x1f\x43\x43hatRoom_JoinVoiceChat_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\"8\n CChatRoom_JoinVoiceChat_Response\x12\x14\n\x0cvoice_chatid\x18\x01 \x01(\x04\"J\n CChatRoom_LeaveVoiceChat_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\"#\n!CChatRoom_LeaveVoiceChat_Response\"\xb4\x01\n#CChatRoom_GetMessageHistory_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x11\n\tlast_time\x18\x03 \x01(\r\x12\x14\n\x0clast_ordinal\x18\x04 \x01(\r\x12\x12\n\nstart_time\x18\x05 \x01(\r\x12\x15\n\rstart_ordinal\x18\x06 \x01(\r\x12\x11\n\tmax_count\x18\x07 \x01(\r\"\x86\x01\n\rServerMessage\x12\x46\n\x07message\x18\x01 \x01(\x0e\x32\x17.EChatRoomServerMessage:\x1ck_EChatRoomServerMsg_Invalid\x12\x14\n\x0cstring_param\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63ountid_param\x18\x03 \x01(\r\"\xa2\x04\n$CChatRoom_GetMessageHistory_Response\x12\x43\n\x08messages\x18\x01 \x03(\x0b\x32\x31.CChatRoom_GetMessageHistory_Response.ChatMessage\x12\x16\n\x0emore_available\x18\x04 \x01(\x08\x1a\x9c\x03\n\x0b\x43hatMessage\x12\x0e\n\x06sender\x18\x01 \x01(\r\x12\x18\n\x10server_timestamp\x18\x02 \x01(\r\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0f\n\x07ordinal\x18\x04 \x01(\r\x12&\n\x0eserver_message\x18\x05 \x01(\x0b\x32\x0e.ServerMessage\x12\x0f\n\x07\x64\x65leted\x18\x06 \x01(\x08\x12T\n\treactions\x18\x07 \x03(\x0b\x32\x41.CChatRoom_GetMessageHistory_Response.ChatMessage.MessageReaction\x1a\xb1\x01\n\x0fMessageReaction\x12\\\n\rreaction_type\x18\x01 \x01(\x0e\x32\x1d.EChatRoomMessageReactionType:&k_EChatRoomMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x02 \x01(\t\x12\x14\n\x0cnum_reactors\x18\x03 \x01(\r\x12\x18\n\x10has_user_reacted\x18\x04 \x01(\x08\"\'\n%CChatRoom_GetMyChatRoomGroups_Request\"\xb4\x05\n*CChatRoom_GetChatRoomGroupSummary_Response\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x17\n\x0f\x63hat_group_name\x18\x02 \x01(\t\x12\x1b\n\x13\x61\x63tive_member_count\x18\x03 \x01(\r\x12!\n\x19\x61\x63tive_voice_member_count\x18\x04 \x01(\r\x12\x17\n\x0f\x64\x65\x66\x61ult_chat_id\x18\x05 \x01(\x04\x12#\n\nchat_rooms\x18\x06 \x03(\x0b\x32\x0f.CChatRoomState\x12\x0e\n\x06\x63lanid\x18\x07 \x01(\r\x12\x1a\n\x12\x63hat_group_tagline\x18\x08 \x01(\t\x12\x17\n\x0f\x61\x63\x63ountid_owner\x18\t \x01(\r\x12\x13\n\x0btop_members\x18\n \x03(\r\x12\x1d\n\x15\x63hat_group_avatar_sha\x18\x0b \x01(\x0c\x12?\n\x04rank\x18\x0c \x01(\x0e\x32\x13.EChatRoomGroupRank:\x1ck_EChatRoomGroupRank_Default\x12\x17\n\x0f\x64\x65\x66\x61ult_role_id\x18\r \x01(\x04\x12\x10\n\x08role_ids\x18\x0e \x03(\x04\x12\'\n\x0crole_actions\x18\x0f \x03(\x0b\x32\x11.CChatRoleActions\x12$\n\x1cwatching_broadcast_accountid\x18\x10 \x01(\r\x12\r\n\x05\x61ppid\x18\x11 \x01(\r\x12(\n\rparty_beacons\x18\x12 \x03(\x0b\x32\x11.CChatPartyBeacon\x12%\n\x1dwatching_broadcast_channel_id\x18\x13 \x01(\x04\x12\x1a\n\x12\x61\x63tive_minigame_id\x18\x14 \x01(\x04\x12\x16\n\x0e\x61vatar_ugc_url\x18\x15 \x01(\t\x12\x10\n\x08\x64isabled\x18\x16 \x01(\x08\"\x93\x01\n\x14\x43\x43hatRoomSummaryPair\x12\x37\n\x15user_chat_group_state\x18\x01 \x01(\x0b\x32\x18.CUserChatRoomGroupState\x12\x42\n\rgroup_summary\x18\x02 \x01(\x0b\x32+.CChatRoom_GetChatRoomGroupSummary_Response\"Y\n&CChatRoom_GetMyChatRoomGroups_Response\x12/\n\x10\x63hat_room_groups\x18\x01 \x03(\x0b\x32\x15.CChatRoomSummaryPair\"@\n\'CChatRoom_GetChatRoomGroupState_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"O\n(CChatRoom_GetChatRoomGroupState_Response\x12#\n\x05state\x18\x01 \x01(\x0b\x32\x14.CChatRoomGroupState\"d\n0CChatRoom_SetAppChatRoomGroupForceActive_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x19\n\x11requesting_app_id\x18\x02 \x01(\r\"`\n1CChatRoom_SetAppChatRoomGroupForceActive_Response\x12\x0e\n\x06result\x18\x01 \x01(\r\x12\x1b\n\x13\x61\x63\x63ounts_in_channel\x18\x02 \x03(\r\"m\n9CChatRoom_SetAppChatRoomGroupStopForceActive_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x19\n\x11requesting_app_id\x18\x02 \x01(\r\"b\n%CChatRoom_AckChatMessage_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x11\n\ttimestamp\x18\x03 \x01(\r\"c\n\"CChatRoom_CreateInviteLink_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x15\n\rseconds_valid\x18\x02 \x01(\r\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\x04\"Q\n#CChatRoom_CreateInviteLink_Response\x12\x13\n\x0binvite_code\x18\x01 \x01(\t\x12\x15\n\rseconds_valid\x18\x02 \x01(\r\":\n#CChatRoom_GetInviteLinkInfo_Request\x12\x13\n\x0binvite_code\x18\x01 \x01(\t\"\x8c\x02\n$CChatRoom_GetInviteLinkInfo_Response\x12\x16\n\x0esteamid_sender\x18\x03 \x01(\x06\x12\x14\n\x0ctime_expires\x18\x04 \x01(\r\x12\x0f\n\x07\x63hat_id\x18\x06 \x01(\x04\x12\x42\n\rgroup_summary\x18\x08 \x01(\x0b\x32+.CChatRoom_GetChatRoomGroupSummary_Response\x12\x37\n\x15user_chat_group_state\x18\t \x01(\x0b\x32\x18.CUserChatRoomGroupState\x12\x18\n\x10time_kick_expire\x18\n \x01(\r\x12\x0e\n\x06\x62\x61nned\x18\x0b \x01(\x08\"w\n\x1f\x43\x43hatRoom_GetInviteInfo_Request\x12\x17\n\x0fsteamid_invitee\x18\x01 \x01(\x06\x12\x15\n\rchat_group_id\x18\x02 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x03 \x01(\x04\x12\x13\n\x0binvite_code\x18\x04 \x01(\t\"\x90\x01\n CChatRoom_GetInviteInfo_Response\x12\x42\n\rgroup_summary\x18\x01 \x01(\x0b\x32+.CChatRoom_GetChatRoomGroupSummary_Response\x12\x18\n\x10time_kick_expire\x18\x02 \x01(\r\x12\x0e\n\x06\x62\x61nned\x18\x03 \x01(\x08\"A\n(CChatRoom_GetInviteLinksForGroup_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"\xd7\x01\n)CChatRoom_GetInviteLinksForGroup_Response\x12I\n\x0cinvite_links\x18\x01 \x03(\x0b\x32\x33.CChatRoom_GetInviteLinksForGroup_Response.LinkInfo\x1a_\n\x08LinkInfo\x12\x13\n\x0binvite_code\x18\x01 \x01(\t\x12\x17\n\x0fsteamid_creator\x18\x02 \x01(\x06\x12\x14\n\x0ctime_expires\x18\x03 \x01(\r\x12\x0f\n\x07\x63hat_id\x18\x04 \x01(\x04\"5\n\x1c\x43\x43hatRoom_GetBanList_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"\xb5\x01\n\x1d\x43\x43hatRoom_GetBanList_Response\x12\x34\n\x04\x62\x61ns\x18\x01 \x03(\x0b\x32&.CChatRoom_GetBanList_Response.BanInfo\x1a^\n\x07\x42\x61nInfo\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x17\n\x0f\x61\x63\x63ountid_actor\x18\x02 \x01(\r\x12\x13\n\x0btime_banned\x18\x03 \x01(\r\x12\x12\n\nban_reason\x18\x04 \x01(\t\"8\n\x1f\x43\x43hatRoom_GetInviteList_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\"X\n\x14\x43\x43hatRoomGroupInvite\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x17\n\x0f\x61\x63\x63ountid_actor\x18\x02 \x01(\r\x12\x14\n\x0ctime_invited\x18\x03 \x01(\r\"J\n CChatRoom_GetInviteList_Response\x12&\n\x07invites\x18\x01 \x03(\x0b\x32\x15.CChatRoomGroupInvite\"P\n\"CChatRoom_DeleteInviteLink_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x13\n\x0binvite_code\x18\x02 \x01(\t\"%\n#CChatRoom_DeleteInviteLink_Response\"\x94\x01\n0CChatRoom_SetSessionActiveChatRoomGroups_Request\x12\x16\n\x0e\x63hat_group_ids\x18\x01 \x03(\x04\x12\"\n\x1a\x63hat_groups_data_requested\x18\x02 \x03(\x04\x12$\n\x1cvirtualize_members_threshold\x18\x03 \x01(\x05\"\x89\x01\n1CChatRoom_SetSessionActiveChatRoomGroups_Response\x12)\n\x0b\x63hat_states\x18\x01 \x03(\x0b\x32\x14.CChatRoomGroupState\x12)\n!virtualize_members_chat_group_ids\x18\x02 \x03(\x04\"\xaa\x06\n-CChatRoom_SetUserChatGroupPreferences_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x63\n\x16\x63hat_group_preferences\x18\x02 \x01(\x0b\x32\x43.CChatRoom_SetUserChatGroupPreferences_Request.ChatGroupPreferences\x12\x61\n\x15\x63hat_room_preferences\x18\x03 \x03(\x0b\x32\x42.CChatRoom_SetUserChatGroupPreferences_Request.ChatRoomPreferences\x1a\x83\x02\n\x14\x43hatGroupPreferences\x12\x65\n\x1a\x64\x65sktop_notification_level\x18\x01 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x64\n\x19mobile_notification_level\x18\x02 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x1e\n\x16unread_indicator_muted\x18\x03 \x01(\x08\x1a\x93\x02\n\x13\x43hatRoomPreferences\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x04\x12\x65\n\x1a\x64\x65sktop_notification_level\x18\x02 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x64\n\x19mobile_notification_level\x18\x03 \x01(\x0e\x32\x1b.EChatRoomNotificationLevel:$k_EChatroomNotificationLevel_Invalid\x12\x1e\n\x16unread_indicator_muted\x18\x04 \x01(\x08\"0\n.CChatRoom_SetUserChatGroupPreferences_Response\"\xc5\x01\n$CChatRoom_DeleteChatMessages_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12?\n\x08messages\x18\x03 \x03(\x0b\x32-.CChatRoom_DeleteChatMessages_Request.Message\x1a\x34\n\x07Message\x12\x18\n\x10server_timestamp\x18\x01 \x01(\r\x12\x0f\n\x07ordinal\x18\x02 \x01(\r\"\'\n%CChatRoom_DeleteChatMessages_Response\"\xf1\x01\n+CChatRoom_UpdateMemberListView_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07view_id\x18\x02 \x01(\x04\x12\r\n\x05start\x18\x03 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x05\x12\x1b\n\x13\x63lient_changenumber\x18\x05 \x01(\x05\x12\x13\n\x0b\x64\x65lete_view\x18\x06 \x01(\x08\x12$\n\x1cpersona_subscribe_accountids\x18\x07 \x03(\x05\x12&\n\x1epersona_unsubscribe_accountids\x18\x08 \x03(\x05\"u\n\x1f\x43\x43hatRoom_SearchMembers_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x11\n\tsearch_id\x18\x02 \x01(\x04\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x13\n\x0bmax_results\x18\x04 \x01(\x05\"\xd4\x01\n CChatRoom_SearchMembers_Response\x12G\n\x10matching_members\x18\x01 \x03(\x0b\x32-.CChatRoom_SearchMembers_Response.MemberMatch\x12\x14\n\x0cstatus_flags\x18\x02 \x01(\r\x1aQ\n\x0bMemberMatch\x12\x11\n\taccountid\x18\x01 \x01(\x05\x12/\n\x07persona\x18\x02 \x01(\x0b\x32\x1e.CMsgClientPersonaState.Friend\"\xfc\x01\n\'CChatRoom_UpdateMessageReaction_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x18\n\x10server_timestamp\x18\x03 \x01(\r\x12\x0f\n\x07ordinal\x18\x04 \x01(\r\x12\\\n\rreaction_type\x18\x05 \x01(\x0e\x32\x1d.EChatRoomMessageReactionType:&k_EChatRoomMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x06 \x01(\t\x12\x0e\n\x06is_add\x18\x07 \x01(\x08\"@\n(CChatRoom_UpdateMessageReaction_Response\x12\x14\n\x0cnum_reactors\x18\x01 \x01(\r\"\x80\x02\n,CChatRoom_GetMessageReactionReactors_Request\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x18\n\x10server_timestamp\x18\x03 \x01(\r\x12\x0f\n\x07ordinal\x18\x04 \x01(\r\x12\\\n\rreaction_type\x18\x05 \x01(\x0e\x32\x1d.EChatRoomMessageReactionType:&k_EChatRoomMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x06 \x01(\t\x12\r\n\x05limit\x18\x07 \x01(\r\"A\n-CChatRoom_GetMessageReactionReactors_Response\x12\x10\n\x08reactors\x18\x01 \x03(\r\"W\n*CClanChatRooms_GetClanChatRoomInfo_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\nautocreate\x18\x02 \x01(\x08:\x04true\"v\n+CClanChatRooms_GetClanChatRoomInfo_Response\x12G\n\x12\x63hat_group_summary\x18\x01 \x01(\x0b\x32+.CChatRoom_GetChatRoomGroupSummary_Response\"[\n-CClanChatRooms_SetClanChatRoomPrivate_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x19\n\x11\x63hat_room_private\x18\x02 \x01(\x08\"K\n.CClanChatRooms_SetClanChatRoomPrivate_Response\x12\x19\n\x11\x63hat_room_private\x18\x01 \x01(\x08\"V\n\rCChatMentions\x12\x13\n\x0bmention_all\x18\x01 \x01(\x08\x12\x14\n\x0cmention_here\x18\x02 \x01(\x08\x12\x1a\n\x12mention_accountids\x18\x03 \x03(\r\"\xb3\x02\n*CChatRoom_IncomingChatMessage_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x16\n\x0esteamid_sender\x18\x03 \x01(\x06\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\r\x12 \n\x08mentions\x18\x06 \x01(\x0b\x32\x0e.CChatMentions\x12\x0f\n\x07ordinal\x18\x07 \x01(\r\x12&\n\x0eserver_message\x18\x08 \x01(\x0b\x32\x0e.ServerMessage\x12\x19\n\x11message_no_bbcode\x18\t \x01(\t\x12\x11\n\tchat_name\x18\n \x01(\t\x12\x18\n\x10notification_key\x18\x0b \x01(\t\"\xea\x01\n*CChatRoom_ChatMessageModified_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12I\n\x08messages\x18\x03 \x03(\x0b\x32\x37.CChatRoom_ChatMessageModified_Notification.ChatMessage\x1aI\n\x0b\x43hatMessage\x12\x18\n\x10server_timestamp\x18\x01 \x01(\r\x12\x0f\n\x07ordinal\x18\x02 \x01(\r\x12\x0f\n\x07\x64\x65leted\x18\x03 \x01(\x08\"\xb6\x01\n(CChatRoom_MemberStateChange_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12 \n\x06member\x18\x02 \x01(\x0b\x32\x10.CChatRoomMember\x12Q\n\x06\x63hange\x18\x03 \x01(\x0e\x32\x1b.EChatRoomMemberStateChange:$k_EChatRoomMemberStateChange_Invalid\"^\n*CChatRoom_ChatRoomHeaderState_Notification\x12\x30\n\x0cheader_state\x18\x01 \x01(\x0b\x32\x1a.CChatRoomGroupHeaderState\"\x86\x01\n/CChatRoom_ChatRoomGroupRoomsChange_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x17\n\x0f\x64\x65\x66\x61ult_chat_id\x18\x02 \x01(\x04\x12#\n\nchat_rooms\x18\x03 \x03(\x0b\x32\x0f.CChatRoomState\"d\n:CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x04\x12\x15\n\rchat_group_id\x18\x02 \x01(\x04\"\xa9\x02\n;ChatRoomClient_NotifyChatGroupUserStateChanged_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x37\n\x15user_chat_group_state\x18\x02 \x01(\x0b\x32\x18.CUserChatRoomGroupState\x12\x42\n\rgroup_summary\x18\x03 \x01(\x0b\x32+.CChatRoom_GetChatRoomGroupSummary_Response\x12V\n\x0buser_action\x18\x04 \x01(\x0e\x32\x1b.EChatRoomMemberStateChange:$k_EChatRoomMemberStateChange_Invalid\"N\n4ChatRoomClient_NotifyChatRoomDisconnect_Notification\x12\x16\n\x0e\x63hat_group_ids\x18\x01 \x03(\x04\"\x84\x01\n\x17\x43\x43hatRoomMemberListView\x12\r\n\x05start\x18\x03 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x05\x12\x13\n\x0btotal_count\x18\x05 \x01(\x05\x12\x1b\n\x13\x63lient_changenumber\x18\x06 \x01(\x05\x12\x1b\n\x13server_changenumber\x18\x07 \x01(\x05\"O\n\x1c\x43\x43hatRoomMemberSummaryCounts\x12\x0e\n\x06ingame\x18\x01 \x01(\x05\x12\x0e\n\x06online\x18\x02 \x01(\x05\x12\x0f\n\x07offline\x18\x03 \x01(\x05\"\xd1\x03\n2CChatRoomClient_MemberListViewUpdated_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07view_id\x18\x02 \x01(\x04\x12&\n\x04view\x18\x03 \x01(\x0b\x32\x18.CChatRoomMemberListView\x12X\n\x07members\x18\x04 \x03(\x0b\x32G.CChatRoomClient_MemberListViewUpdated_Notification.MemberListViewEntry\x12\x14\n\x0cstatus_flags\x18\x05 \x01(\r\x12\x35\n\x0emember_summary\x18\x06 \x01(\x0b\x32\x1d.CChatRoomMemberSummaryCounts\x12;\n\x13subscribed_personas\x18\x07 \x03(\x0b\x32\x1e.CMsgClientPersonaState.Friend\x1ag\n\x13MemberListViewEntry\x12\x0c\n\x04rank\x18\x01 \x01(\x05\x12\x11\n\taccountid\x18\x02 \x01(\r\x12/\n\x07persona\x18\x03 \x01(\x0b\x32\x1e.CMsgClientPersonaState.Friend\"\x8c\x02\n&CChatRoom_MessageReaction_Notification\x12\x15\n\rchat_group_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63hat_id\x18\x02 \x01(\x04\x12\x18\n\x10server_timestamp\x18\x03 \x01(\r\x12\x0f\n\x07ordinal\x18\x04 \x01(\r\x12\x0f\n\x07reactor\x18\x05 \x01(\x06\x12\\\n\rreaction_type\x18\x06 \x01(\x0e\x32\x1d.EChatRoomMessageReactionType:&k_EChatRoomMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x07 \x01(\t\x12\x0e\n\x06is_add\x18\x08 \x01(\x08\"\xdf\x15\n2CChatUsability_ClientUsabilityMetrics_Notification\x12\x16\n\x0emetrics_run_id\x18\x01 \x01(\r\x12\x14\n\x0c\x63lient_build\x18\x02 \x01(\r\x12\x17\n\x0fmetrics_version\x18\x03 \x01(\r\x12\x0e\n\x06in_web\x18\x04 \x01(\x08\x12N\n\x08settings\x18\n \x01(\x0b\x32<.CChatUsability_ClientUsabilityMetrics_Notification.Settings\x12Y\n\x0evoice_settings\x18\x0b \x01(\x0b\x32\x41.CChatUsability_ClientUsabilityMetrics_Notification.VoiceSettings\x12M\n\x08ui_state\x18\x0c \x01(\x0b\x32;.CChatUsability_ClientUsabilityMetrics_Notification.UIState\x12L\n\x07metrics\x18\r \x01(\x0b\x32;.CChatUsability_ClientUsabilityMetrics_Notification.Metrics\x1a\xd9\x06\n\x08Settings\x12!\n\x19notifications_show_ingame\x18\x01 \x01(\x08\x12!\n\x19notifications_show_online\x18\x02 \x01(\x08\x12\"\n\x1anotifications_show_message\x18\x03 \x01(\x08\x12.\n&notifications_events_and_announcements\x18\x04 \x01(\x08\x12\x1a\n\x12sounds_play_ingame\x18\x05 \x01(\x08\x12\x1a\n\x12sounds_play_online\x18\x06 \x01(\x08\x12\x1b\n\x13sounds_play_message\x18\x07 \x01(\x08\x12\'\n\x1fsounds_events_and_announcements\x18\x08 \x01(\x08\x12\x1e\n\x16\x61lways_new_chat_window\x18\t \x01(\x08\x12\'\n\x1f\x66orce_alphabetic_friend_sorting\x18\n \x01(\x08\x12\x17\n\x0f\x63hat_flash_mode\x18\x0b \x01(\x05\x12\x1b\n\x13remember_open_chats\x18\x0c \x01(\x08\x12\x1c\n\x14\x63ompact_quick_access\x18\r \x01(\x08\x12\x1c\n\x14\x63ompact_friends_list\x18\x0e \x01(\x08\x12\x31\n)notifications_show_chat_room_notification\x18\x0f \x01(\x08\x12*\n\"sounds_play_chat_room_notification\x18\x10 \x01(\x08\x12*\n\"hide_offline_friends_in_tag_groups\x18\x11 \x01(\x08\x12 \n\x18hide_categorized_friends\x18\x12 \x01(\x08\x12*\n\"categorize_in_game_friends_by_game\x18\x13 \x01(\x08\x12\x16\n\x0e\x63hat_font_size\x18\x14 \x01(\x05\x12\x17\n\x0fuse24hour_clock\x18\x15 \x01(\x08\x12\x1b\n\x13\x64o_not_disturb_mode\x18\x16 \x01(\x08\x12\x1e\n\x16\x64isable_embed_inlining\x18\x17 \x01(\x08\x12\x19\n\x11sign_into_friends\x18\x18 \x01(\x08\x12\x18\n\x10\x61nimated_avatars\x18\x19 \x01(\x08\x1a\xea\x02\n\rVoiceSettings\x12\x18\n\x10voice_input_gain\x18\x01 \x01(\x02\x12\x19\n\x11voice_output_gain\x18\x02 \x01(\x02\x12\x18\n\x10noise_gate_level\x18\x03 \x01(\x05\x12#\n\x1bvoice_use_echo_cancellation\x18\x04 \x01(\x08\x12$\n\x1cvoice_use_noise_cancellation\x18\x05 \x01(\x08\x12#\n\x1bvoice_use_auto_gain_control\x18\x06 \x01(\x08\x12 \n\x18selected_non_default_mic\x18\x07 \x01(\x08\x12#\n\x1bselected_non_default_output\x18\x08 \x01(\x08\x12\x1c\n\x14push_to_talk_enabled\x18\t \x01(\x08\x12\x1c\n\x14push_to_mute_enabled\x18\n \x01(\x08\x12\x17\n\x0fplay_ptt_sounds\x18\x0b \x01(\x08\x1a\xfd\x05\n\x07UIState\x12\x1b\n\x13\x66riends_list_height\x18\x01 \x01(\x05\x12\x1a\n\x12\x66riends_list_width\x18\x02 \x01(\x05\x12\x1b\n\x13\x66riends_list_docked\x18\x03 \x01(\x08\x12\x1e\n\x16\x66riends_list_collapsed\x18\x04 \x01(\x08\x12\'\n\x1f\x66riends_list_group_chats_height\x18\x05 \x01(\x05\x12\x1c\n\x14\x66riends_list_visible\x18\x06 \x01(\x08\x12\x1a\n\x12\x63hat_popups_opened\x18\x07 \x01(\x05\x12\x1e\n\x16group_chat_tabs_opened\x18\x08 \x01(\x05\x12\x1f\n\x17\x66riend_chat_tabs_opened\x18\t \x01(\x05\x12\x19\n\x11\x63hat_window_width\x18\n \x01(\x05\x12\x1a\n\x12\x63hat_window_height\x18\x0b \x01(\x05\x12l\n\x11\x63\x61tegory_collapse\x18\x0c \x01(\x0b\x32Q.CChatUsability_ClientUsabilityMetrics_Notification.UIState.CategoryCollapseState\x12%\n\x1dgroup_chat_left_col_collapsed\x18\r \x01(\x05\x12&\n\x1egroup_chat_right_col_collapsed\x18\x0e \x01(\x05\x12 \n\x18in_one_on_one_voice_chat\x18\x0f \x01(\x08\x12\x1b\n\x13in_group_voice_chat\x18\x10 \x01(\x08\x1a\xa4\x01\n\x15\x43\x61tegoryCollapseState\x12\x19\n\x11in_game_collapsed\x18\x01 \x01(\x08\x12\x18\n\x10online_collapsed\x18\x02 \x01(\x08\x12\x19\n\x11offline_collapsed\x18\x03 \x01(\x08\x12\x1d\n\x15game_groups_collapsed\x18\x04 \x01(\x05\x12\x1c\n\x14\x63\x61tegories_collapsed\x18\x05 \x01(\x05\x1a\xc0\x02\n\x07Metrics\x12\x15\n\rfriends_count\x18\x01 \x01(\x05\x12\x1e\n\x16\x66riends_category_count\x18\x02 \x01(\x05\x12!\n\x19\x66riends_categorized_count\x18\x03 \x01(\x05\x12\x1c\n\x14\x66riends_online_count\x18\x04 \x01(\x05\x12\x1d\n\x15\x66riends_in_game_count\x18\x05 \x01(\x05\x12\'\n\x1f\x66riends_in_game_singleton_count\x18\x06 \x01(\x05\x12\x18\n\x10game_group_count\x18\x07 \x01(\x05\x12\x1e\n\x16\x66riends_favorite_count\x18\x08 \x01(\x05\x12\x18\n\x10group_chat_count\x18\t \x01(\x05\x12!\n\x19group_chat_favorite_count\x18\n \x01(\x05\"S\n9CChatUsability_RequestClientUsabilityMetrics_Notification\x12\x16\n\x0emetrics_run_id\x18\x01 \x01(\r*\x9c\x01\n\x12\x45\x43hatRoomJoinState\x12 \n\x1ck_EChatRoomJoinState_Default\x10\x00\x12\x1d\n\x19k_EChatRoomJoinState_None\x10\x01\x12\x1f\n\x1bk_EChatRoomJoinState_Joined\x10\x02\x12$\n k_EChatRoomJoinState_TestInvalid\x10\x63*\xa4\x02\n\x12\x45\x43hatRoomGroupRank\x12 \n\x1ck_EChatRoomGroupRank_Default\x10\x00\x12\x1f\n\x1bk_EChatRoomGroupRank_Viewer\x10\n\x12\x1e\n\x1ak_EChatRoomGroupRank_Guest\x10\x0f\x12\x1f\n\x1bk_EChatRoomGroupRank_Member\x10\x14\x12\"\n\x1ek_EChatRoomGroupRank_Moderator\x10\x1e\x12 \n\x1ck_EChatRoomGroupRank_Officer\x10(\x12\x1e\n\x1ak_EChatRoomGroupRank_Owner\x10\x32\x12$\n k_EChatRoomGroupRank_TestInvalid\x10\x63*\xf4\x01\n\x1a\x45\x43hatRoomNotificationLevel\x12(\n$k_EChatroomNotificationLevel_Invalid\x10\x00\x12%\n!k_EChatroomNotificationLevel_None\x10\x01\x12*\n&k_EChatroomNotificationLevel_MentionMe\x10\x02\x12+\n\'k_EChatroomNotificationLevel_MentionAll\x10\x03\x12,\n(k_EChatroomNotificationLevel_AllMessages\x10\x04*\x97\x03\n\x16\x45\x43hatRoomServerMessage\x12 \n\x1ck_EChatRoomServerMsg_Invalid\x10\x00\x12\'\n#k_EChatRoomServerMsg_RenameChatRoom\x10\x01\x12\x1f\n\x1bk_EChatRoomServerMsg_Joined\x10\x02\x12\x1f\n\x1bk_EChatRoomServerMsg_Parted\x10\x03\x12\x1f\n\x1bk_EChatRoomServerMsg_Kicked\x10\x04\x12 \n\x1ck_EChatRoomServerMsg_Invited\x10\x05\x12(\n$k_EChatRoomServerMsg_InviteDismissed\x10\x08\x12/\n+k_EChatRoomServerMsg_ChatRoomTaglineChanged\x10\t\x12.\n*k_EChatRoomServerMsg_ChatRoomAvatarChanged\x10\n\x12\"\n\x1ek_EChatRoomServerMsg_AppCustom\x10\x0b*\xa3\x01\n\x1c\x45\x43hatRoomMessageReactionType\x12*\n&k_EChatRoomMessageReactionType_Invalid\x10\x00\x12+\n\'k_EChatRoomMessageReactionType_Emoticon\x10\x01\x12*\n&k_EChatRoomMessageReactionType_Sticker\x10\x02*\xcb\x03\n\x1a\x45\x43hatRoomMemberStateChange\x12(\n$k_EChatRoomMemberStateChange_Invalid\x10\x00\x12\'\n#k_EChatRoomMemberStateChange_Joined\x10\x01\x12\'\n#k_EChatRoomMemberStateChange_Parted\x10\x02\x12\'\n#k_EChatRoomMemberStateChange_Kicked\x10\x03\x12(\n$k_EChatRoomMemberStateChange_Invited\x10\x04\x12,\n(k_EChatRoomMemberStateChange_RankChanged\x10\x07\x12\x30\n,k_EChatRoomMemberStateChange_InviteDismissed\x10\x08\x12&\n\"k_EChatRoomMemberStateChange_Muted\x10\t\x12\'\n#k_EChatRoomMemberStateChange_Banned\x10\n\x12-\n)k_EChatRoomMemberStateChange_RolesChanged\x10\x0c\x32{\n\x04\x43hat\x12s\n\x1aRequestFriendPersonaStates\x12).CChat_RequestFriendPersonaStates_Request\x1a*.CChat_RequestFriendPersonaStates_Response2\x9d(\n\x08\x43hatRoom\x12\x66\n\x13\x43reateChatRoomGroup\x12&.CChatRoom_CreateChatRoomGroup_Request\x1a\'.CChatRoom_CreateChatRoomGroup_Response\x12`\n\x11SaveChatRoomGroup\x12$.CChatRoom_SaveChatRoomGroup_Request\x1a%.CChatRoom_SaveChatRoomGroup_Response\x12\x66\n\x13RenameChatRoomGroup\x12&.CChatRoom_RenameChatRoomGroup_Request\x1a\'.CChatRoom_RenameChatRoomGroup_Response\x12r\n\x17SetChatRoomGroupTagline\x12*.CChatRoom_SetChatRoomGroupTagline_Request\x1a+.CChatRoom_SetChatRoomGroupTagline_Response\x12o\n\x16SetChatRoomGroupAvatar\x12).CChatRoom_SetChatRoomGroupAvatar_Request\x1a*.CChatRoom_SetChatRoomGroupAvatar_Response\x12\x90\x01\n!SetChatRoomGroupWatchingBroadcast\x12\x34.CChatRoom_SetChatRoomGroupWatchingBroadcast_Request\x1a\x35.CChatRoom_SetChatRoomGroupWatchingBroadcast_Response\x12\x81\x01\n\x1cJoinMiniGameForChatRoomGroup\x12/.CChatRoom_JoinMiniGameForChatRoomGroup_Request\x1a\x30.CChatRoom_JoinMiniGameForChatRoomGroup_Response\x12~\n\x1b\x45ndMiniGameForChatRoomGroup\x12..CChatRoom_EndMiniGameForChatRoomGroup_Request\x1a/.CChatRoom_EndMiniGameForChatRoomGroup_Response\x12L\n\x0fMuteUserInGroup\x12\x1b.CChatRoom_MuteUser_Request\x1a\x1c.CChatRoom_MuteUser_Response\x12N\n\x11KickUserFromGroup\x12\x1b.CChatRoom_KickUser_Request\x1a\x1c.CChatRoom_KickUser_Response\x12Z\n\x0fSetUserBanState\x12\".CChatRoom_SetUserBanState_Request\x1a#.CChatRoom_SetUserBanState_Response\x12X\n\x13RevokeInviteToGroup\x12\x1f.CChatRoom_RevokeInvite_Request\x1a .CChatRoom_RevokeInvite_Response\x12K\n\nCreateRole\x12\x1d.CChatRoom_CreateRole_Request\x1a\x1e.CChatRoom_CreateRole_Response\x12\x45\n\x08GetRoles\x12\x1b.CChatRoom_GetRoles_Request\x1a\x1c.CChatRoom_GetRoles_Response\x12K\n\nRenameRole\x12\x1d.CChatRoom_RenameRole_Request\x1a\x1e.CChatRoom_RenameRole_Response\x12N\n\x0bReorderRole\x12\x1e.CChatRoom_ReorderRole_Request\x1a\x1f.CChatRoom_ReorderRole_Response\x12K\n\nDeleteRole\x12\x1d.CChatRoom_DeleteRole_Request\x1a\x1e.CChatRoom_DeleteRole_Response\x12W\n\x0eGetRoleActions\x12!.CChatRoom_GetRoleActions_Request\x1a\".CChatRoom_GetRoleActions_Response\x12\x63\n\x12ReplaceRoleActions\x12%.CChatRoom_ReplaceRoleActions_Request\x1a&.CChatRoom_ReplaceRoleActions_Response\x12T\n\rAddRoleToUser\x12 .CChatRoom_AddRoleToUser_Request\x1a!.CChatRoom_AddRoleToUser_Response\x12Z\n\x0fGetRolesForUser\x12\".CChatRoom_GetRolesForUser_Request\x1a#.CChatRoom_GetRolesForUser_Response\x12\x63\n\x12\x44\x65leteRoleFromUser\x12%.CChatRoom_DeleteRoleFromUser_Request\x1a&.CChatRoom_DeleteRoleFromUser_Response\x12`\n\x11JoinChatRoomGroup\x12$.CChatRoom_JoinChatRoomGroup_Request\x1a%.CChatRoom_JoinChatRoomGroup_Response\x12~\n\x1bInviteFriendToChatRoomGroup\x12..CChatRoom_InviteFriendToChatRoomGroup_Request\x1a/.CChatRoom_InviteFriendToChatRoomGroup_Response\x12\x63\n\x12LeaveChatRoomGroup\x12%.CChatRoom_LeaveChatRoomGroup_Request\x1a&.CChatRoom_LeaveChatRoomGroup_Response\x12W\n\x0e\x43reateChatRoom\x12!.CChatRoom_CreateChatRoom_Request\x1a\".CChatRoom_CreateChatRoom_Response\x12W\n\x0e\x44\x65leteChatRoom\x12!.CChatRoom_DeleteChatRoom_Request\x1a\".CChatRoom_DeleteChatRoom_Response\x12W\n\x0eRenameChatRoom\x12!.CChatRoom_RenameChatRoom_Request\x1a\".CChatRoom_RenameChatRoom_Response\x12Z\n\x0fReorderChatRoom\x12\".CChatRoom_ReorderChatRoom_Request\x1a#.CChatRoom_ReorderChatRoom_Response\x12Z\n\x0fSendChatMessage\x12\".CChatRoom_SendChatMessage_Request\x1a#.CChatRoom_SendChatMessage_Response\x12T\n\rJoinVoiceChat\x12 .CChatRoom_JoinVoiceChat_Request\x1a!.CChatRoom_JoinVoiceChat_Response\x12W\n\x0eLeaveVoiceChat\x12!.CChatRoom_LeaveVoiceChat_Request\x1a\".CChatRoom_LeaveVoiceChat_Response\x12`\n\x11GetMessageHistory\x12$.CChatRoom_GetMessageHistory_Request\x1a%.CChatRoom_GetMessageHistory_Response\x12\x66\n\x13GetMyChatRoomGroups\x12&.CChatRoom_GetMyChatRoomGroups_Request\x1a\'.CChatRoom_GetMyChatRoomGroups_Response\x12l\n\x15GetChatRoomGroupState\x12(.CChatRoom_GetChatRoomGroupState_Request\x1a).CChatRoom_GetChatRoomGroupState_Response\x12\x87\x01\n\x1eSetAppChatRoomGroupForceActive\x12\x31.CChatRoom_SetAppChatRoomGroupForceActive_Request\x1a\x32.CChatRoom_SetAppChatRoomGroupForceActive_Response\x12m\n\"SetAppChatRoomGroupStopForceActive\x12:.CChatRoom_SetAppChatRoomGroupStopForceActive_Notification\x1a\x0b.NoResponse\x12\x45\n\x0e\x41\x63kChatMessage\x12&.CChatRoom_AckChatMessage_Notification\x1a\x0b.NoResponse\x12]\n\x10\x43reateInviteLink\x12#.CChatRoom_CreateInviteLink_Request\x1a$.CChatRoom_CreateInviteLink_Response\x12`\n\x11GetInviteLinkInfo\x12$.CChatRoom_GetInviteLinkInfo_Request\x1a%.CChatRoom_GetInviteLinkInfo_Response\x12T\n\rGetInviteInfo\x12 .CChatRoom_GetInviteInfo_Request\x1a!.CChatRoom_GetInviteInfo_Response\x12o\n\x16GetInviteLinksForGroup\x12).CChatRoom_GetInviteLinksForGroup_Request\x1a*.CChatRoom_GetInviteLinksForGroup_Response\x12K\n\nGetBanList\x12\x1d.CChatRoom_GetBanList_Request\x1a\x1e.CChatRoom_GetBanList_Response\x12T\n\rGetInviteList\x12 .CChatRoom_GetInviteList_Request\x1a!.CChatRoom_GetInviteList_Response\x12]\n\x10\x44\x65leteInviteLink\x12#.CChatRoom_DeleteInviteLink_Request\x1a$.CChatRoom_DeleteInviteLink_Response\x12\x87\x01\n\x1eSetSessionActiveChatRoomGroups\x12\x31.CChatRoom_SetSessionActiveChatRoomGroups_Request\x1a\x32.CChatRoom_SetSessionActiveChatRoomGroups_Response\x12~\n\x1bSetUserChatGroupPreferences\x12..CChatRoom_SetUserChatGroupPreferences_Request\x1a/.CChatRoom_SetUserChatGroupPreferences_Response\x12\x63\n\x12\x44\x65leteChatMessages\x12%.CChatRoom_DeleteChatMessages_Request\x1a&.CChatRoom_DeleteChatMessages_Response\x12Q\n\x14UpdateMemberListView\x12,.CChatRoom_UpdateMemberListView_Notification\x1a\x0b.NoResponse\x12T\n\rSearchMembers\x12 .CChatRoom_SearchMembers_Request\x1a!.CChatRoom_SearchMembers_Response\x12l\n\x15UpdateMessageReaction\x12(.CChatRoom_UpdateMessageReaction_Request\x1a).CChatRoom_UpdateMessageReaction_Response\x12{\n\x1aGetMessageReactionReactors\x12-.CChatRoom_GetMessageReactionReactors_Request\x1a..CChatRoom_GetMessageReactionReactors_Response2\xfc\x01\n\rClanChatRooms\x12p\n\x13GetClanChatRoomInfo\x12+.CClanChatRooms_GetClanChatRoomInfo_Request\x1a,.CClanChatRooms_GetClanChatRoomInfo_Response\x12y\n\x16SetClanChatRoomPrivate\x12..CClanChatRooms_SetClanChatRoomPrivate_Request\x1a/.CClanChatRooms_SetClanChatRoomPrivate_Response2\x95\x08\n\x0e\x43hatRoomClient\x12U\n\x19NotifyIncomingChatMessage\x12+.CChatRoom_IncomingChatMessage_Notification\x1a\x0b.NoResponse\x12U\n\x19NotifyChatMessageModified\x12+.CChatRoom_ChatMessageModified_Notification\x1a\x0b.NoResponse\x12Q\n\x17NotifyMemberStateChange\x12).CChatRoom_MemberStateChange_Notification\x1a\x0b.NoResponse\x12[\n\x1fNotifyChatRoomHeaderStateChange\x12+.CChatRoom_ChatRoomHeaderState_Notification\x1a\x0b.NoResponse\x12_\n\x1eNotifyChatRoomGroupRoomsChange\x12\x30.CChatRoom_ChatRoomGroupRoomsChange_Notification\x1a\x0b.NoResponse\x12o\n#NotifyShouldRejoinChatRoomVoiceChat\x12;.CChatRoom_NotifyShouldRejoinChatRoomVoiceChat_Notification\x1a\x0b.NoResponse\x12l\n\x1fNotifyChatGroupUserStateChanged\x12<.ChatRoomClient_NotifyChatGroupUserStateChanged_Notification\x1a\x0b.NoResponse\x12O\n\x18NotifyAckChatMessageEcho\x12&.CChatRoom_AckChatMessage_Notification\x1a\x0b.NoResponse\x12^\n\x18NotifyChatRoomDisconnect\x12\x35.ChatRoomClient_NotifyChatRoomDisconnect_Notification\x1a\x0b.NoResponse\x12_\n\x1bNotifyMemberListViewUpdated\x12\x33.CChatRoomClient_MemberListViewUpdated_Notification\x1a\x0b.NoResponse\x12M\n\x15NotifyMessageReaction\x12\'.CChatRoom_MessageReaction_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x32q\n\rChatUsability\x12`\n\x1cNotifyClientUsabilityMetrics\x12\x33.CChatUsability_ClientUsabilityMetrics_Notification\x1a\x0b.NoResponse2\x8b\x01\n\x13\x43hatUsabilityClient\x12n\n#NotifyRequestClientUsabilityMetrics\x12:.CChatUsability_RequestClientUsabilityMetrics_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_chat_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CHATROOMCLIENT._options = None
  _CHATROOMCLIENT._serialized_options = b'\300\265\030\002'
  _CHATUSABILITYCLIENT._options = None
  _CHATUSABILITYCLIENT._serialized_options = b'\300\265\030\002'
  _ECHATROOMJOINSTATE._serialized_start=19805
  _ECHATROOMJOINSTATE._serialized_end=19961
  _ECHATROOMGROUPRANK._serialized_start=19964
  _ECHATROOMGROUPRANK._serialized_end=20256
  _ECHATROOMNOTIFICATIONLEVEL._serialized_start=20259
  _ECHATROOMNOTIFICATIONLEVEL._serialized_end=20503
  _ECHATROOMSERVERMESSAGE._serialized_start=20506
  _ECHATROOMSERVERMESSAGE._serialized_end=20913
  _ECHATROOMMESSAGEREACTIONTYPE._serialized_start=20916
  _ECHATROOMMESSAGEREACTIONTYPE._serialized_end=21079
  _ECHATROOMMEMBERSTATECHANGE._serialized_start=21082
  _ECHATROOMMEMBERSTATECHANGE._serialized_end=21541
  _CCHAT_REQUESTFRIENDPERSONASTATES_REQUEST._serialized_start=130
  _CCHAT_REQUESTFRIENDPERSONASTATES_REQUEST._serialized_end=172
  _CCHAT_REQUESTFRIENDPERSONASTATES_RESPONSE._serialized_start=174
  _CCHAT_REQUESTFRIENDPERSONASTATES_RESPONSE._serialized_end=217
  _CCHATROOM_CREATECHATROOMGROUP_REQUEST._serialized_start=220
  _CCHATROOM_CREATECHATROOMGROUP_REQUEST._serialized_end=426
  _CCHATROLE._serialized_start=428
  _CCHATROLE._serialized_end=487
  _CCHATROLEACTIONS._serialized_start=490
  _CCHATROLEACTIONS._serialized_end=830
  _CCHATPARTYBEACON._serialized_start=832
  _CCHATPARTYBEACON._serialized_end=931
  _CCHATROOMGROUPHEADERSTATE._serialized_start=934
  _CCHATROOMGROUPHEADERSTATE._serialized_end=1378
  _CCHATROOMMEMBER._serialized_start=1381
  _CCHATROOMMEMBER._serialized_end=1592
  _CCHATROOMSTATE._serialized_start=1595
  _CCHATROOMSTATE._serialized_end=1797
  _CCHATROOMGROUPSTATE._serialized_start=1800
  _CCHATROOMGROUPSTATE._serialized_end=2002
  _CUSERCHATROOMSTATE._serialized_start=2005
  _CUSERCHATROOMSTATE._serialized_end=2384
  _CUSERCHATROOMGROUPSTATE._serialized_start=2387
  _CUSERCHATROOMGROUPSTATE._serialized_end=2780
  _CCHATROOM_CREATECHATROOMGROUP_RESPONSE._serialized_start=2783
  _CCHATROOM_CREATECHATROOMGROUP_RESPONSE._serialized_end=2934
  _CCHATROOM_SAVECHATROOMGROUP_REQUEST._serialized_start=2936
  _CCHATROOM_SAVECHATROOMGROUP_REQUEST._serialized_end=3010
  _CCHATROOM_SAVECHATROOMGROUP_RESPONSE._serialized_start=3012
  _CCHATROOM_SAVECHATROOMGROUP_RESPONSE._serialized_end=3050
  _CCHATROOM_RENAMECHATROOMGROUP_REQUEST._serialized_start=3052
  _CCHATROOM_RENAMECHATROOMGROUP_REQUEST._serialized_end=3128
  _CCHATROOM_RENAMECHATROOMGROUP_RESPONSE._serialized_start=3130
  _CCHATROOM_RENAMECHATROOMGROUP_RESPONSE._serialized_end=3184
  _CCHATROOM_SETCHATROOMGROUPTAGLINE_REQUEST._serialized_start=3186
  _CCHATROOM_SETCHATROOMGROUPTAGLINE_REQUEST._serialized_end=3269
  _CCHATROOM_SETCHATROOMGROUPTAGLINE_RESPONSE._serialized_start=3271
  _CCHATROOM_SETCHATROOMGROUPTAGLINE_RESPONSE._serialized_end=3315
  _CCHATROOM_SETCHATROOMGROUPAVATAR_REQUEST._serialized_start=3317
  _CCHATROOM_SETCHATROOMGROUPAVATAR_REQUEST._serialized_end=3402
  _CCHATROOM_SETCHATROOMGROUPAVATAR_RESPONSE._serialized_start=3404
  _CCHATROOM_SETCHATROOMGROUPAVATAR_RESPONSE._serialized_end=3447
  _CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_REQUEST._serialized_start=3450
  _CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_REQUEST._serialized_end=3603
  _CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_RESPONSE._serialized_start=3605
  _CCHATROOM_SETCHATROOMGROUPWATCHINGBROADCAST_RESPONSE._serialized_end=3659
  _CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_REQUEST._serialized_start=3661
  _CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_REQUEST._serialized_end=3749
  _CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_RESPONSE._serialized_start=3751
  _CCHATROOM_JOINMINIGAMEFORCHATROOMGROUP_RESPONSE._serialized_end=3821
  _CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_REQUEST._serialized_start=3823
  _CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_REQUEST._serialized_end=3931
  _CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_RESPONSE._serialized_start=3933
  _CCHATROOM_ENDMINIGAMEFORCHATROOMGROUP_RESPONSE._serialized_end=3981
  _CCHATROOM_MUTEUSER_REQUEST._serialized_start=3983
  _CCHATROOM_MUTEUSER_REQUEST._serialized_end=4071
  _CCHATROOM_MUTEUSER_RESPONSE._serialized_start=4073
  _CCHATROOM_MUTEUSER_RESPONSE._serialized_end=4102
  _CCHATROOM_KICKUSER_REQUEST._serialized_start=4104
  _CCHATROOM_KICKUSER_REQUEST._serialized_end=4192
  _CCHATROOM_KICKUSER_RESPONSE._serialized_start=4194
  _CCHATROOM_KICKUSER_RESPONSE._serialized_end=4223
  _CCHATROOM_SETUSERBANSTATE_REQUEST._serialized_start=4225
  _CCHATROOM_SETUSERBANSTATE_REQUEST._serialized_end=4319
  _CCHATROOM_SETUSERBANSTATE_RESPONSE._serialized_start=4321
  _CCHATROOM_SETUSERBANSTATE_RESPONSE._serialized_end=4357
  _CCHATROOM_REVOKEINVITE_REQUEST._serialized_start=4359
  _CCHATROOM_REVOKEINVITE_REQUEST._serialized_end=4431
  _CCHATROOM_REVOKEINVITE_RESPONSE._serialized_start=4433
  _CCHATROOM_REVOKEINVITE_RESPONSE._serialized_end=4466
  _CCHATROOM_CREATEROLE_REQUEST._serialized_start=4468
  _CCHATROOM_CREATEROLE_REQUEST._serialized_end=4535
  _CCHATROOM_CREATEROLE_RESPONSE._serialized_start=4537
  _CCHATROOM_CREATEROLE_RESPONSE._serialized_end=4604
  _CCHATROOM_GETROLES_REQUEST._serialized_start=4606
  _CCHATROOM_GETROLES_REQUEST._serialized_end=4657
  _CCHATROOM_GETROLES_RESPONSE._serialized_start=4659
  _CCHATROOM_GETROLES_RESPONSE._serialized_end=4715
  _CCHATROOM_RENAMEROLE_REQUEST._serialized_start=4717
  _CCHATROOM_RENAMEROLE_REQUEST._serialized_end=4801
  _CCHATROOM_RENAMEROLE_RESPONSE._serialized_start=4803
  _CCHATROOM_RENAMEROLE_RESPONSE._serialized_end=4834
  _CCHATROOM_REORDERROLE_REQUEST._serialized_start=4836
  _CCHATROOM_REORDERROLE_REQUEST._serialized_end=4924
  _CCHATROOM_REORDERROLE_RESPONSE._serialized_start=4926
  _CCHATROOM_REORDERROLE_RESPONSE._serialized_end=4958
  _CCHATROOM_DELETEROLE_REQUEST._serialized_start=4960
  _CCHATROOM_DELETEROLE_REQUEST._serialized_end=5030
  _CCHATROOM_DELETEROLE_RESPONSE._serialized_start=5032
  _CCHATROOM_DELETEROLE_RESPONSE._serialized_end=5063
  _CCHATROOM_GETROLEACTIONS_REQUEST._serialized_start=5065
  _CCHATROOM_GETROLEACTIONS_REQUEST._serialized_end=5139
  _CCHATROOM_GETROLEACTIONS_RESPONSE._serialized_start=5141
  _CCHATROOM_GETROLEACTIONS_RESPONSE._serialized_end=5212
  _CCHATROOM_REPLACEROLEACTIONS_REQUEST._serialized_start=5214
  _CCHATROOM_REPLACEROLEACTIONS_REQUEST._serialized_end=5328
  _CCHATROOM_REPLACEROLEACTIONS_RESPONSE._serialized_start=5330
  _CCHATROOM_REPLACEROLEACTIONS_RESPONSE._serialized_end=5369
  _CCHATROOM_ADDROLETOUSER_REQUEST._serialized_start=5371
  _CCHATROOM_ADDROLETOUSER_REQUEST._serialized_end=5461
  _CCHATROOM_ADDROLETOUSER_RESPONSE._serialized_start=5463
  _CCHATROOM_ADDROLETOUSER_RESPONSE._serialized_end=5497
  _CCHATROOM_GETROLESFORUSER_REQUEST._serialized_start=5499
  _CCHATROOM_GETROLESFORUSER_REQUEST._serialized_end=5574
  _CCHATROOM_GETROLESFORUSER_RESPONSE._serialized_start=5576
  _CCHATROOM_GETROLESFORUSER_RESPONSE._serialized_end=5630
  _CCHATROOM_DELETEROLEFROMUSER_REQUEST._serialized_start=5632
  _CCHATROOM_DELETEROLEFROMUSER_REQUEST._serialized_end=5727
  _CCHATROOM_DELETEROLEFROMUSER_RESPONSE._serialized_start=5729
  _CCHATROOM_DELETEROLEFROMUSER_RESPONSE._serialized_end=5768
  _CCHATROOM_JOINCHATROOMGROUP_REQUEST._serialized_start=5770
  _CCHATROOM_JOINCHATROOMGROUP_REQUEST._serialized_end=5868
  _CCHATROOM_JOINCHATROOMGROUP_RESPONSE._serialized_start=5871
  _CCHATROOM_JOINCHATROOMGROUP_RESPONSE._serialized_end=6040
  _CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_REQUEST._serialized_start=6043
  _CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_REQUEST._serialized_end=6177
  _CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_RESPONSE._serialized_start=6179
  _CCHATROOM_INVITEFRIENDTOCHATROOMGROUP_RESPONSE._serialized_end=6227
  _CCHATROOM_LEAVECHATROOMGROUP_REQUEST._serialized_start=6229
  _CCHATROOM_LEAVECHATROOMGROUP_REQUEST._serialized_end=6290
  _CCHATROOM_LEAVECHATROOMGROUP_RESPONSE._serialized_start=6292
  _CCHATROOM_LEAVECHATROOMGROUP_RESPONSE._serialized_end=6331
  _CCHATROOM_CREATECHATROOM_REQUEST._serialized_start=6333
  _CCHATROOM_CREATECHATROOM_REQUEST._serialized_end=6425
  _CCHATROOM_CREATECHATROOM_RESPONSE._serialized_start=6427
  _CCHATROOM_CREATECHATROOM_RESPONSE._serialized_end=6498
  _CCHATROOM_DELETECHATROOM_REQUEST._serialized_start=6500
  _CCHATROOM_DELETECHATROOM_REQUEST._serialized_end=6574
  _CCHATROOM_DELETECHATROOM_RESPONSE._serialized_start=6576
  _CCHATROOM_DELETECHATROOM_RESPONSE._serialized_end=6611
  _CCHATROOM_RENAMECHATROOM_REQUEST._serialized_start=6613
  _CCHATROOM_RENAMECHATROOM_REQUEST._serialized_end=6701
  _CCHATROOM_RENAMECHATROOM_RESPONSE._serialized_start=6703
  _CCHATROOM_RENAMECHATROOM_RESPONSE._serialized_end=6738
  _CCHATROOM_REORDERCHATROOM_REQUEST._serialized_start=6740
  _CCHATROOM_REORDERCHATROOM_REQUEST._serialized_end=6843
  _CCHATROOM_REORDERCHATROOM_RESPONSE._serialized_start=6845
  _CCHATROOM_REORDERCHATROOM_RESPONSE._serialized_end=6881
  _CCHATROOM_SENDCHATMESSAGE_REQUEST._serialized_start=6883
  _CCHATROOM_SENDCHATMESSAGE_REQUEST._serialized_end=6999
  _CCHATROOM_SENDCHATMESSAGE_RESPONSE._serialized_start=7002
  _CCHATROOM_SENDCHATMESSAGE_RESPONSE._serialized_end=7140
  _CCHATROOM_JOINVOICECHAT_REQUEST._serialized_start=7142
  _CCHATROOM_JOINVOICECHAT_REQUEST._serialized_end=7215
  _CCHATROOM_JOINVOICECHAT_RESPONSE._serialized_start=7217
  _CCHATROOM_JOINVOICECHAT_RESPONSE._serialized_end=7273
  _CCHATROOM_LEAVEVOICECHAT_REQUEST._serialized_start=7275
  _CCHATROOM_LEAVEVOICECHAT_REQUEST._serialized_end=7349
  _CCHATROOM_LEAVEVOICECHAT_RESPONSE._serialized_start=7351
  _CCHATROOM_LEAVEVOICECHAT_RESPONSE._serialized_end=7386
  _CCHATROOM_GETMESSAGEHISTORY_REQUEST._serialized_start=7389
  _CCHATROOM_GETMESSAGEHISTORY_REQUEST._serialized_end=7569
  _SERVERMESSAGE._serialized_start=7572
  _SERVERMESSAGE._serialized_end=7706
  _CCHATROOM_GETMESSAGEHISTORY_RESPONSE._serialized_start=7709
  _CCHATROOM_GETMESSAGEHISTORY_RESPONSE._serialized_end=8255
  _CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE._serialized_start=7843
  _CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE._serialized_end=8255
  _CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE_MESSAGEREACTION._serialized_start=8078
  _CCHATROOM_GETMESSAGEHISTORY_RESPONSE_CHATMESSAGE_MESSAGEREACTION._serialized_end=8255
  _CCHATROOM_GETMYCHATROOMGROUPS_REQUEST._serialized_start=8257
  _CCHATROOM_GETMYCHATROOMGROUPS_REQUEST._serialized_end=8296
  _CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE._serialized_start=8299
  _CCHATROOM_GETCHATROOMGROUPSUMMARY_RESPONSE._serialized_end=8991
  _CCHATROOMSUMMARYPAIR._serialized_start=8994
  _CCHATROOMSUMMARYPAIR._serialized_end=9141
  _CCHATROOM_GETMYCHATROOMGROUPS_RESPONSE._serialized_start=9143
  _CCHATROOM_GETMYCHATROOMGROUPS_RESPONSE._serialized_end=9232
  _CCHATROOM_GETCHATROOMGROUPSTATE_REQUEST._serialized_start=9234
  _CCHATROOM_GETCHATROOMGROUPSTATE_REQUEST._serialized_end=9298
  _CCHATROOM_GETCHATROOMGROUPSTATE_RESPONSE._serialized_start=9300
  _CCHATROOM_GETCHATROOMGROUPSTATE_RESPONSE._serialized_end=9379
  _CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_REQUEST._serialized_start=9381
  _CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_REQUEST._serialized_end=9481
  _CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_RESPONSE._serialized_start=9483
  _CCHATROOM_SETAPPCHATROOMGROUPFORCEACTIVE_RESPONSE._serialized_end=9579
  _CCHATROOM_SETAPPCHATROOMGROUPSTOPFORCEACTIVE_NOTIFICATION._serialized_start=9581
  _CCHATROOM_SETAPPCHATROOMGROUPSTOPFORCEACTIVE_NOTIFICATION._serialized_end=9690
  _CCHATROOM_ACKCHATMESSAGE_NOTIFICATION._serialized_start=9692
  _CCHATROOM_ACKCHATMESSAGE_NOTIFICATION._serialized_end=9790
  _CCHATROOM_CREATEINVITELINK_REQUEST._serialized_start=9792
  _CCHATROOM_CREATEINVITELINK_REQUEST._serialized_end=9891
  _CCHATROOM_CREATEINVITELINK_RESPONSE._serialized_start=9893
  _CCHATROOM_CREATEINVITELINK_RESPONSE._serialized_end=9974
  _CCHATROOM_GETINVITELINKINFO_REQUEST._serialized_start=9976
  _CCHATROOM_GETINVITELINKINFO_REQUEST._serialized_end=10034
  _CCHATROOM_GETINVITELINKINFO_RESPONSE._serialized_start=10037
  _CCHATROOM_GETINVITELINKINFO_RESPONSE._serialized_end=10305
  _CCHATROOM_GETINVITEINFO_REQUEST._serialized_start=10307
  _CCHATROOM_GETINVITEINFO_REQUEST._serialized_end=10426
  _CCHATROOM_GETINVITEINFO_RESPONSE._serialized_start=10429
  _CCHATROOM_GETINVITEINFO_RESPONSE._serialized_end=10573
  _CCHATROOM_GETINVITELINKSFORGROUP_REQUEST._serialized_start=10575
  _CCHATROOM_GETINVITELINKSFORGROUP_REQUEST._serialized_end=10640
  _CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE._serialized_start=10643
  _CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE._serialized_end=10858
  _CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE_LINKINFO._serialized_start=10763
  _CCHATROOM_GETINVITELINKSFORGROUP_RESPONSE_LINKINFO._serialized_end=10858
  _CCHATROOM_GETBANLIST_REQUEST._serialized_start=10860
  _CCHATROOM_GETBANLIST_REQUEST._serialized_end=10913
  _CCHATROOM_GETBANLIST_RESPONSE._serialized_start=10916
  _CCHATROOM_GETBANLIST_RESPONSE._serialized_end=11097
  _CCHATROOM_GETBANLIST_RESPONSE_BANINFO._serialized_start=11003
  _CCHATROOM_GETBANLIST_RESPONSE_BANINFO._serialized_end=11097
  _CCHATROOM_GETINVITELIST_REQUEST._serialized_start=11099
  _CCHATROOM_GETINVITELIST_REQUEST._serialized_end=11155
  _CCHATROOMGROUPINVITE._serialized_start=11157
  _CCHATROOMGROUPINVITE._serialized_end=11245
  _CCHATROOM_GETINVITELIST_RESPONSE._serialized_start=11247
  _CCHATROOM_GETINVITELIST_RESPONSE._serialized_end=11321
  _CCHATROOM_DELETEINVITELINK_REQUEST._serialized_start=11323
  _CCHATROOM_DELETEINVITELINK_REQUEST._serialized_end=11403
  _CCHATROOM_DELETEINVITELINK_RESPONSE._serialized_start=11405
  _CCHATROOM_DELETEINVITELINK_RESPONSE._serialized_end=11442
  _CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_REQUEST._serialized_start=11445
  _CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_REQUEST._serialized_end=11593
  _CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_RESPONSE._serialized_start=11596
  _CCHATROOM_SETSESSIONACTIVECHATROOMGROUPS_RESPONSE._serialized_end=11733
  _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST._serialized_start=11736
  _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST._serialized_end=12546
  _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATGROUPPREFERENCES._serialized_start=12009
  _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATGROUPPREFERENCES._serialized_end=12268
  _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATROOMPREFERENCES._serialized_start=12271
  _CCHATROOM_SETUSERCHATGROUPPREFERENCES_REQUEST_CHATROOMPREFERENCES._serialized_end=12546
  _CCHATROOM_SETUSERCHATGROUPPREFERENCES_RESPONSE._serialized_start=12548
  _CCHATROOM_SETUSERCHATGROUPPREFERENCES_RESPONSE._serialized_end=12596
  _CCHATROOM_DELETECHATMESSAGES_REQUEST._serialized_start=12599
  _CCHATROOM_DELETECHATMESSAGES_REQUEST._serialized_end=12796
  _CCHATROOM_DELETECHATMESSAGES_REQUEST_MESSAGE._serialized_start=12744
  _CCHATROOM_DELETECHATMESSAGES_REQUEST_MESSAGE._serialized_end=12796
  _CCHATROOM_DELETECHATMESSAGES_RESPONSE._serialized_start=12798
  _CCHATROOM_DELETECHATMESSAGES_RESPONSE._serialized_end=12837
  _CCHATROOM_UPDATEMEMBERLISTVIEW_NOTIFICATION._serialized_start=12840
  _CCHATROOM_UPDATEMEMBERLISTVIEW_NOTIFICATION._serialized_end=13081
  _CCHATROOM_SEARCHMEMBERS_REQUEST._serialized_start=13083
  _CCHATROOM_SEARCHMEMBERS_REQUEST._serialized_end=13200
  _CCHATROOM_SEARCHMEMBERS_RESPONSE._serialized_start=13203
  _CCHATROOM_SEARCHMEMBERS_RESPONSE._serialized_end=13415
  _CCHATROOM_SEARCHMEMBERS_RESPONSE_MEMBERMATCH._serialized_start=13334
  _CCHATROOM_SEARCHMEMBERS_RESPONSE_MEMBERMATCH._serialized_end=13415
  _CCHATROOM_UPDATEMESSAGEREACTION_REQUEST._serialized_start=13418
  _CCHATROOM_UPDATEMESSAGEREACTION_REQUEST._serialized_end=13670
  _CCHATROOM_UPDATEMESSAGEREACTION_RESPONSE._serialized_start=13672
  _CCHATROOM_UPDATEMESSAGEREACTION_RESPONSE._serialized_end=13736
  _CCHATROOM_GETMESSAGEREACTIONREACTORS_REQUEST._serialized_start=13739
  _CCHATROOM_GETMESSAGEREACTIONREACTORS_REQUEST._serialized_end=13995
  _CCHATROOM_GETMESSAGEREACTIONREACTORS_RESPONSE._serialized_start=13997
  _CCHATROOM_GETMESSAGEREACTIONREACTORS_RESPONSE._serialized_end=14062
  _CCLANCHATROOMS_GETCLANCHATROOMINFO_REQUEST._serialized_start=14064
  _CCLANCHATROOMS_GETCLANCHATROOMINFO_REQUEST._serialized_end=14151
  _CCLANCHATROOMS_GETCLANCHATROOMINFO_RESPONSE._serialized_start=14153
  _CCLANCHATROOMS_GETCLANCHATROOMINFO_RESPONSE._serialized_end=14271
  _CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_REQUEST._serialized_start=14273
  _CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_REQUEST._serialized_end=14364
  _CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_RESPONSE._serialized_start=14366
  _CCLANCHATROOMS_SETCLANCHATROOMPRIVATE_RESPONSE._serialized_end=14441
  _CCHATMENTIONS._serialized_start=14443
  _CCHATMENTIONS._serialized_end=14529
  _CCHATROOM_INCOMINGCHATMESSAGE_NOTIFICATION._serialized_start=14532
  _CCHATROOM_INCOMINGCHATMESSAGE_NOTIFICATION._serialized_end=14839
  _CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION._serialized_start=14842
  _CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION._serialized_end=15076
  _CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION_CHATMESSAGE._serialized_start=15003
  _CCHATROOM_CHATMESSAGEMODIFIED_NOTIFICATION_CHATMESSAGE._serialized_end=15076
  _CCHATROOM_MEMBERSTATECHANGE_NOTIFICATION._serialized_start=15079
  _CCHATROOM_MEMBERSTATECHANGE_NOTIFICATION._serialized_end=15261
  _CCHATROOM_CHATROOMHEADERSTATE_NOTIFICATION._serialized_start=15263
  _CCHATROOM_CHATROOMHEADERSTATE_NOTIFICATION._serialized_end=15357
  _CCHATROOM_CHATROOMGROUPROOMSCHANGE_NOTIFICATION._serialized_start=15360
  _CCHATROOM_CHATROOMGROUPROOMSCHANGE_NOTIFICATION._serialized_end=15494
  _CCHATROOM_NOTIFYSHOULDREJOINCHATROOMVOICECHAT_NOTIFICATION._serialized_start=15496
  _CCHATROOM_NOTIFYSHOULDREJOINCHATROOMVOICECHAT_NOTIFICATION._serialized_end=15596
  _CHATROOMCLIENT_NOTIFYCHATGROUPUSERSTATECHANGED_NOTIFICATION._serialized_start=15599
  _CHATROOMCLIENT_NOTIFYCHATGROUPUSERSTATECHANGED_NOTIFICATION._serialized_end=15896
  _CHATROOMCLIENT_NOTIFYCHATROOMDISCONNECT_NOTIFICATION._serialized_start=15898
  _CHATROOMCLIENT_NOTIFYCHATROOMDISCONNECT_NOTIFICATION._serialized_end=15976
  _CCHATROOMMEMBERLISTVIEW._serialized_start=15979
  _CCHATROOMMEMBERLISTVIEW._serialized_end=16111
  _CCHATROOMMEMBERSUMMARYCOUNTS._serialized_start=16113
  _CCHATROOMMEMBERSUMMARYCOUNTS._serialized_end=16192
  _CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION._serialized_start=16195
  _CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION._serialized_end=16660
  _CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION_MEMBERLISTVIEWENTRY._serialized_start=16557
  _CCHATROOMCLIENT_MEMBERLISTVIEWUPDATED_NOTIFICATION_MEMBERLISTVIEWENTRY._serialized_end=16660
  _CCHATROOM_MESSAGEREACTION_NOTIFICATION._serialized_start=16663
  _CCHATROOM_MESSAGEREACTION_NOTIFICATION._serialized_end=16931
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION._serialized_start=16934
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION._serialized_end=19717
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_SETTINGS._serialized_start=17404
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_SETTINGS._serialized_end=18261
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_VOICESETTINGS._serialized_start=18264
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_VOICESETTINGS._serialized_end=18626
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE._serialized_start=18629
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE._serialized_end=19394
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE_CATEGORYCOLLAPSESTATE._serialized_start=19230
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_UISTATE_CATEGORYCOLLAPSESTATE._serialized_end=19394
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_METRICS._serialized_start=19397
  _CCHATUSABILITY_CLIENTUSABILITYMETRICS_NOTIFICATION_METRICS._serialized_end=19717
  _CCHATUSABILITY_REQUESTCLIENTUSABILITYMETRICS_NOTIFICATION._serialized_start=19719
  _CCHATUSABILITY_REQUESTCLIENTUSABILITYMETRICS_NOTIFICATION._serialized_end=19802
  _CHAT._serialized_start=21543
  _CHAT._serialized_end=21666
  _CHATROOM._serialized_start=21669
  _CHATROOM._serialized_end=26818
  _CLANCHATROOMS._serialized_start=26821
  _CLANCHATROOMS._serialized_end=27073
  _CHATROOMCLIENT._serialized_start=27076
  _CHATROOMCLIENT._serialized_end=28121
  _CHATUSABILITY._serialized_start=28123
  _CHATUSABILITY._serialized_end=28236
  _CHATUSABILITYCLIENT._serialized_start=28239
  _CHATUSABILITYCLIENT._serialized_end=28378
_builder.BuildServices(DESCRIPTOR, 'steammessages_chat_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_remoteclient_discovery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*steammessages_remoteclient_discovery.proto\"\xcf\x01\n\x1f\x43MsgRemoteClientBroadcastHeader\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12R\n\x08msg_type\x18\x02 \x01(\x0e\x32\x1a.ERemoteClientBroadcastMsg:$k_ERemoteClientBroadcastMsgDiscovery\x12\x13\n\x0binstance_id\x18\x03 \x01(\x04\x12\x1a\n\x12\x64\x65vice_id_OBSOLETE\x18\x04 \x01(\x04\x12\x14\n\x0c\x64\x65vice_token\x18\x05 \x01(\x0c\"\xd8\x05\n\x1f\x43MsgRemoteClientBroadcastStatus\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x13\n\x0bmin_version\x18\x02 \x01(\x05\x12\x14\n\x0c\x63onnect_port\x18\x03 \x01(\r\x12\x10\n\x08hostname\x18\x04 \x01(\t\x12\x18\n\x10\x65nabled_services\x18\x06 \x01(\r\x12\x11\n\x06ostype\x18\x07 \x01(\x05:\x01\x30\x12\x0f\n\x07is64bit\x18\x08 \x01(\x08\x12\x34\n\x05users\x18\t \x03(\x0b\x32%.CMsgRemoteClientBroadcastStatus.User\x12\x11\n\teuniverse\x18\x0b \x01(\x05\x12\x11\n\ttimestamp\x18\x0c \x01(\r\x12\x15\n\rscreen_locked\x18\r \x01(\x08\x12\x15\n\rgames_running\x18\x0e \x01(\x08\x12\x15\n\rmac_addresses\x18\x0f \x03(\t\x12\x1f\n\x17\x64ownload_lan_peer_group\x18\x10 \x01(\r\x12\x1b\n\x13\x62roadcasting_active\x18\x11 \x01(\x08\x12\x11\n\tvr_active\x18\x12 \x01(\x08\x12\x1a\n\x12\x63ontent_cache_port\x18\x13 \x01(\r\x12\x14\n\x0cip_addresses\x18\x14 \x03(\t\x12\x19\n\x11public_ip_address\x18\x15 \x01(\t\x12\x19\n\x11remoteplay_active\x18\x16 \x01(\x08\x12\x1a\n\x12supported_services\x18\x17 \x01(\r\x12\x12\n\nsteam_deck\x18\x18 \x01(\x08\x12\x15\n\rsteam_version\x18\x19 \x01(\x04\x12\x38\n\x0cvr_link_caps\x18\x1a \x01(\x0e\x32\x0c.EVRLinkCaps:\x14k_EVRLinkCapsUnknown\x12 \n\x18vr_link_invite_client_id\x18\x1b \x01(\x06\x1a,\n\x04User\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x13\n\x0b\x61uth_key_id\x18\x02 \x01(\r\"I\n\"CMsgRemoteClientBroadcastDiscovery\x12\x0f\n\x07seq_num\x18\x01 \x01(\r\x12\x12\n\nclient_ids\x18\x02 \x03(\x04\"A\n+CMsgRemoteClientBroadcastClientIDDeconflict\x12\x12\n\nclient_ids\x18\x02 \x03(\x04\"\xf5\x03\n$CMsgRemoteDeviceAuthorizationRequest\x12\x14\n\x0c\x64\x65vice_token\x18\x01 \x02(\x0c\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x19\n\x11\x65ncrypted_request\x18\x03 \x02(\x0c\x12\x10\n\x08\x61uth_key\x18\x04 \x01(\x0c\x12\x12\n\nrequest_id\x18\x05 \x01(\r\x1a\xa7\x02\n\x11\x43KeyEscrow_Ticket\x12\x10\n\x08password\x18\x01 \x01(\x0c\x12\x12\n\nidentifier\x18\x02 \x01(\x04\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\x12\x11\n\ttimestamp\x18\x04 \x01(\r\x12\x66\n\x05usage\x18\x05 \x01(\x0e\x32\x35.CMsgRemoteDeviceAuthorizationRequest.EKeyEscrowUsage: k_EKeyEscrowUsageStreamingDevice\x12\x13\n\x0b\x64\x65vice_name\x18\x06 \x01(\t\x12\x14\n\x0c\x64\x65vice_model\x18\x07 \x01(\t\x12\x15\n\rdevice_serial\x18\x08 \x01(\t\x12\x1e\n\x16\x64\x65vice_provisioning_id\x18\t \x01(\r\"7\n\x0f\x45KeyEscrowUsage\x12$\n k_EKeyEscrowUsageStreamingDevice\x10\x00\",\n*CMsgRemoteDeviceAuthorizationCancelRequest\"\xb8\x01\n%CMsgRemoteDeviceAuthorizationResponse\x12V\n\x06result\x18\x01 \x02(\x0e\x32!.ERemoteDeviceAuthorizationResult:#k_ERemoteDeviceAuthorizationSuccess\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x10\n\x08\x61uth_key\x18\x03 \x01(\x0c\x12\x14\n\x0c\x64\x65vice_token\x18\x04 \x01(\x0c\"\x80\x01\n&CMsgRemoteDeviceAuthorizationConfirmed\x12V\n\x06result\x18\x01 \x02(\x0e\x32!.ERemoteDeviceAuthorizationResult:#k_ERemoteDeviceAuthorizationSuccess\"\x91\x06\n CMsgRemoteDeviceStreamingRequest\x12\x12\n\nrequest_id\x18\x01 \x02(\r\x12\x1c\n\x14maximum_resolution_x\x18\x02 \x01(\x05\x12\x1c\n\x14maximum_resolution_y\x18\x03 \x01(\x05\x12\x1e\n\x13\x61udio_channel_count\x18\x04 \x01(\x05:\x01\x32\x12\x16\n\x0e\x64\x65vice_version\x18\x05 \x01(\t\x12\x16\n\x0estream_desktop\x18\x06 \x01(\x08\x12\x14\n\x0c\x64\x65vice_token\x18\x07 \x01(\x0c\x12\x0b\n\x03pin\x18\x08 \x01(\x0c\x12$\n\x16\x65nable_video_streaming\x18\t \x01(\x08:\x04true\x12$\n\x16\x65nable_audio_streaming\x18\n \x01(\x08:\x04true\x12$\n\x16\x65nable_input_streaming\x18\x0b \x01(\x08:\x04true\x12\x14\n\x0cnetwork_test\x18\x0c \x01(\x08\x12\x11\n\tclient_id\x18\r \x01(\x04\x12.\n\x13supported_transport\x18\x0e \x03(\x0e\x32\x11.EStreamTransport\x12\x12\n\nrestricted\x18\x0f \x01(\x08\x12O\n\x0b\x66orm_factor\x18\x10 \x01(\x0e\x32\x18.EStreamDeviceFormFactor: k_EStreamDeviceFormFactorUnknown\x12\x15\n\rgamepad_count\x18\x11 \x01(\x05\x12\x43\n\x08gamepads\x18\x12 \x03(\x0b\x32\x31.CMsgRemoteDeviceStreamingRequest.ReservedGamepad\x12\x0e\n\x06gameid\x18\x13 \x01(\x04\x12\x46\n\x10stream_interface\x18\x14 \x01(\x0e\x32\x11.EStreamInterface:\x19k_EStreamInterfaceDefault\x1a\x46\n\x0fReservedGamepad\x12\x17\n\x0f\x63ontroller_type\x18\x01 \x01(\r\x12\x1a\n\x12\x63ontroller_subtype\x18\x02 \x01(\r\"<\n&CMsgRemoteDeviceStreamingCancelRequest\x12\x12\n\nrequest_id\x18\x01 \x02(\r\"I\n!CMsgRemoteDeviceStreamingProgress\x12\x12\n\nrequest_id\x18\x01 \x02(\r\x12\x10\n\x08progress\x18\x02 \x01(\x02\"\x95\x02\n!CMsgRemoteDeviceStreamingResponse\x12\x12\n\nrequest_id\x18\x01 \x02(\r\x12N\n\x06result\x18\x02 \x02(\x0e\x32\x1d.ERemoteDeviceStreamingResult:\x1fk_ERemoteDeviceStreamingSuccess\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\x1d\n\x15\x65ncrypted_session_key\x18\x04 \x01(\x0c\x12;\n\ttransport\x18\x06 \x01(\x0e\x32\x11.EStreamTransport:\x15k_EStreamTransportUDP\x12\x14\n\x0crelay_server\x18\x07 \x01(\t\x12\x0c\n\x04\x63\x65rt\x18\x08 \x01(\t\"\\\n\x1c\x43MsgRemoteDeviceProofRequest\x12\x11\n\tchallenge\x18\x01 \x02(\x0c\x12\x12\n\nrequest_id\x18\x02 \x01(\r\x12\x15\n\rupdate_secret\x18\x03 \x01(\x08\"]\n\x1d\x43MsgRemoteDeviceProofResponse\x12\x10\n\x08response\x18\x01 \x02(\x0c\x12\x12\n\nrequest_id\x18\x02 \x01(\r\x12\x16\n\x0eupdated_secret\x18\x03 \x01(\x08\"G\n%CMsgRemoteDeviceStreamTransportSignal\x12\r\n\x05token\x18\x01 \x01(\x0c\x12\x0f\n\x07payload\x18\x02 \x01(\x0c*\xfd\x04\n\x19\x45RemoteClientBroadcastMsg\x12(\n$k_ERemoteClientBroadcastMsgDiscovery\x10\x00\x12%\n!k_ERemoteClientBroadcastMsgStatus\x10\x01\x12&\n\"k_ERemoteClientBroadcastMsgOffline\x10\x02\x12\'\n#k_ERemoteDeviceAuthorizationRequest\x10\x03\x12(\n$k_ERemoteDeviceAuthorizationResponse\x10\x04\x12#\n\x1fk_ERemoteDeviceStreamingRequest\x10\x05\x12$\n k_ERemoteDeviceStreamingResponse\x10\x06\x12\x1f\n\x1bk_ERemoteDeviceProofRequest\x10\x07\x12 \n\x1ck_ERemoteDeviceProofResponse\x10\x08\x12-\n)k_ERemoteDeviceAuthorizationCancelRequest\x10\t\x12)\n%k_ERemoteDeviceStreamingCancelRequest\x10\n\x12\x31\n-k_ERemoteClientBroadcastMsgClientIDDeconflict\x10\x0b\x12(\n$k_ERemoteDeviceStreamTransportSignal\x10\x0c\x12$\n k_ERemoteDeviceStreamingProgress\x10\r\x12)\n%k_ERemoteDeviceAuthorizationConfirmed\x10\x0e*\x80\x02\n\x14\x45RemoteClientService\x12\x1e\n\x1ak_ERemoteClientServiceNone\x10\x00\x12\'\n#k_ERemoteClientServiceRemoteControl\x10\x01\x12\'\n#k_ERemoteClientServiceGameStreaming\x10\x02\x12%\n!k_ERemoteClientServiceSiteLicense\x10\x04\x12&\n\"k_ERemoteClientServiceContentCache\x10\x08\x12\'\n#k_ERemoteClientServiceContentServer\x10\x10*\x8d\x01\n\x0b\x45VRLinkCaps\x12\x18\n\x14k_EVRLinkCapsUnknown\x10\x00\x12\x1a\n\x16k_EVRLinkCapsAvailable\x10\x01\x12\x1e\n\x1ak_EVRLinkCapsUnimplemented\x10\x02\x12(\n$k_EVRLinkCapsMissingHardwareEncoding\x10\x03*\x97\x03\n ERemoteDeviceAuthorizationResult\x12\'\n#k_ERemoteDeviceAuthorizationSuccess\x10\x00\x12&\n\"k_ERemoteDeviceAuthorizationDenied\x10\x01\x12+\n\'k_ERemoteDeviceAuthorizationNotLoggedIn\x10\x02\x12\'\n#k_ERemoteDeviceAuthorizationOffline\x10\x03\x12$\n k_ERemoteDeviceAuthorizationBusy\x10\x04\x12*\n&k_ERemoteDeviceAuthorizationInProgress\x10\x05\x12(\n$k_ERemoteDeviceAuthorizationTimedOut\x10\x06\x12&\n\"k_ERemoteDeviceAuthorizationFailed\x10\x07\x12(\n$k_ERemoteDeviceAuthorizationCanceled\x10\x08*\xf8\x01\n\x17\x45StreamDeviceFormFactor\x12$\n k_EStreamDeviceFormFactorUnknown\x10\x00\x12\"\n\x1ek_EStreamDeviceFormFactorPhone\x10\x01\x12#\n\x1fk_EStreamDeviceFormFactorTablet\x10\x02\x12%\n!k_EStreamDeviceFormFactorComputer\x10\x03\x12\x1f\n\x1bk_EStreamDeviceFormFactorTV\x10\x04\x12&\n\"k_EStreamDeviceFormFactorVRHeadset\x10\x05*\xee\x01\n\x10\x45StreamTransport\x12\x1a\n\x16k_EStreamTransportNone\x10\x00\x12\x19\n\x15k_EStreamTransportUDP\x10\x01\x12\x1e\n\x1ak_EStreamTransportUDPRelay\x10\x02\x12%\n!k_EStreamTransportWebRTC_OBSOLETE\x10\x03\x12\x19\n\x15k_EStreamTransportSDR\x10\x04\x12\x1d\n\x19k_EStreamTransportUDP_SNS\x10\x05\x12\"\n\x1ek_EStreamTransportUDPRelay_SNS\x10\x06*\xb4\x01\n\x10\x45StreamInterface\x12\x1d\n\x19k_EStreamInterfaceDefault\x10\x00\x12!\n\x1dk_EStreamInterfaceRecentGames\x10\x01\x12 \n\x1ck_EStreamInterfaceBigPicture\x10\x02\x12\x1d\n\x19k_EStreamInterfaceDesktop\x10\x03\x12\x1d\n\x19k_EStreamInterfaceSteamVR\x10\x04*\xb9\x05\n\x1c\x45RemoteDeviceStreamingResult\x12#\n\x1fk_ERemoteDeviceStreamingSuccess\x10\x00\x12(\n$k_ERemoteDeviceStreamingUnauthorized\x10\x01\x12(\n$k_ERemoteDeviceStreamingScreenLocked\x10\x02\x12\"\n\x1ek_ERemoteDeviceStreamingFailed\x10\x03\x12 \n\x1ck_ERemoteDeviceStreamingBusy\x10\x04\x12&\n\"k_ERemoteDeviceStreamingInProgress\x10\x05\x12$\n k_ERemoteDeviceStreamingCanceled\x10\x06\x12/\n+k_ERemoteDeviceStreamingDriversNotInstalled\x10\x07\x12$\n k_ERemoteDeviceStreamingDisabled\x10\x08\x12.\n*k_ERemoteDeviceStreamingBroadcastingActive\x10\t\x12$\n k_ERemoteDeviceStreamingVRActive\x10\n\x12\'\n#k_ERemoteDeviceStreamingPINRequired\x10\x0b\x12\x30\n,k_ERemoteDeviceStreamingTransportUnavailable\x10\x0c\x12%\n!k_ERemoteDeviceStreamingInvisible\x10\r\x12,\n(k_ERemoteDeviceStreamingGameLaunchFailed\x10\x0e\x12/\n+k_ERemoteDeviceStreamingSteamVRNotInstalled\x10\x0f\x42\x02H\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_remoteclient_discovery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001'
  _EREMOTECLIENTBROADCASTMSG._serialized_start=3465
  _EREMOTECLIENTBROADCASTMSG._serialized_end=4102
  _EREMOTECLIENTSERVICE._serialized_start=4105
  _EREMOTECLIENTSERVICE._serialized_end=4361
  _EVRLINKCAPS._serialized_start=4364
  _EVRLINKCAPS._serialized_end=4505
  _EREMOTEDEVICEAUTHORIZATIONRESULT._serialized_start=4508
  _EREMOTEDEVICEAUTHORIZATIONRESULT._serialized_end=4915
  _ESTREAMDEVICEFORMFACTOR._serialized_start=4918
  _ESTREAMDEVICEFORMFACTOR._serialized_end=5166
  _ESTREAMTRANSPORT._serialized_start=5169
  _ESTREAMTRANSPORT._serialized_end=5407
  _ESTREAMINTERFACE._serialized_start=5410
  _ESTREAMINTERFACE._serialized_end=5590
  _EREMOTEDEVICESTREAMINGRESULT._serialized_start=5593
  _EREMOTEDEVICESTREAMINGRESULT._serialized_end=6290
  _CMSGREMOTECLIENTBROADCASTHEADER._serialized_start=47
  _CMSGREMOTECLIENTBROADCASTHEADER._serialized_end=254
  _CMSGREMOTECLIENTBROADCASTSTATUS._serialized_start=257
  _CMSGREMOTECLIENTBROADCASTSTATUS._serialized_end=985
  _CMSGREMOTECLIENTBROADCASTSTATUS_USER._serialized_start=941
  _CMSGREMOTECLIENTBROADCASTSTATUS_USER._serialized_end=985
  _CMSGREMOTECLIENTBROADCASTDISCOVERY._serialized_start=987
  _CMSGREMOTECLIENTBROADCASTDISCOVERY._serialized_end=1060
  _CMSGREMOTECLIENTBROADCASTCLIENTIDDECONFLICT._serialized_start=1062
  _CMSGREMOTECLIENTBROADCASTCLIENTIDDECONFLICT._serialized_end=1127
  _CMSGREMOTEDEVICEAUTHORIZATIONREQUEST._serialized_start=1130
  _CMSGREMOTEDEVICEAUTHORIZATIONREQUEST._serialized_end=1631
  _CMSGREMOTEDEVICEAUTHORIZATIONREQUEST_CKEYESCROW_TICKET._serialized_start=1279
  _CMSGREMOTEDEVICEAUTHORIZATIONREQUEST_CKEYESCROW_TICKET._serialized_end=1574
  _CMSGREMOTEDEVICEAUTHORIZATIONREQUEST_EKEYESCROWUSAGE._serialized_start=1576
  _CMSGREMOTEDEVICEAUTHORIZATIONREQUEST_EKEYESCROWUSAGE._serialized_end=1631
  _CMSGREMOTEDEVICEAUTHORIZATIONCANCELREQUEST._serialized_start=1633
  _CMSGREMOTEDEVICEAUTHORIZATIONCANCELREQUEST._serialized_end=1677
  _CMSGREMOTEDEVICEAUTHORIZATIONRESPONSE._serialized_start=1680
  _CMSGREMOTEDEVICEAUTHORIZATIONRESPONSE._serialized_end=1864
  _CMSGREMOTEDEVICEAUTHORIZATIONCONFIRMED._serialized_start=1867
  _CMSGREMOTEDEVICEAUTHORIZATIONCONFIRMED._serialized_end=1995
  _CMSGREMOTEDEVICESTREAMINGREQUEST._serialized_start=1998
  _CMSGREMOTEDEVICESTREAMINGREQUEST._serialized_end=2783
  _CMSGREMOTEDEVICESTREAMINGREQUEST_RESERVEDGAMEPAD._serialized_start=2713
  _CMSGREMOTEDEVICESTREAMINGREQUEST_RESERVEDGAMEPAD._serialized_end=2783
  _CMSGREMOTEDEVICESTREAMINGCANCELREQUEST._serialized_start=2785
  _CMSGREMOTEDEVICESTREAMINGCANCELREQUEST._serialized_end=2845
  _CMSGREMOTEDEVICESTREAMINGPROGRESS._serialized_start=2847
  _CMSGREMOTEDEVICESTREAMINGPROGRESS._serialized_end=2920
  _CMSGREMOTEDEVICESTREAMINGRESPONSE._serialized_start=2923
  _CMSGREMOTEDEVICESTREAMINGRESPONSE._serialized_end=3200
  _CMSGREMOTEDEVICEPROOFREQUEST._serialized_start=3202
  _CMSGREMOTEDEVICEPROOFREQUEST._serialized_end=3294
  _CMSGREMOTEDEVICEPROOFRESPONSE._serialized_start=3296
  _CMSGREMOTEDEVICEPROOFRESPONSE._serialized_end=3389
  _CMSGREMOTEDEVICESTREAMTRANSPORTSIGNAL._serialized_start=3391
  _CMSGREMOTEDEVICESTREAMTRANSPORTSIGNAL._serialized_end=3462
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_gameservers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fsteammessages_gameservers.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"@\n*CGameServers_GetServerSteamIDsByIP_Request\x12\x12\n\nserver_ips\x18\x01 \x03(\t\"\x90\x01\n%CGameServers_IPsWithSteamIDs_Response\x12>\n\x07servers\x18\x01 \x03(\x0b\x32-.CGameServers_IPsWithSteamIDs_Response.Server\x1a\'\n\x06Server\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\"E\n*CGameServers_GetServerIPsBySteamID_Request\x12\x17\n\x0fserver_steamids\x18\x01 \x03(\x06\"\x80\x02\n\"CGameServers_QueryByFakeIP_Request\x12\x0f\n\x07\x66\x61ke_ip\x18\x01 \x01(\r\x12\x11\n\tfake_port\x18\x02 \x01(\r\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12Q\n\nquery_type\x18\x04 \x01(\x0e\x32..CGameServers_QueryByFakeIP_Request.EQueryType:\rQuery_Invalid\"S\n\nEQueryType\x12\x11\n\rQuery_Invalid\x10\x00\x12\x0e\n\nQuery_Ping\x10\x01\x12\x11\n\rQuery_Players\x10\x02\x12\x0f\n\x0bQuery_Rules\x10\x03\"\xd0\x03\n\x1b\x43MsgGameServerPingQueryData\x12!\n\tserver_ip\x18\x01 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x12\n\nquery_port\x18\x02 \x01(\r\x12\x11\n\tgame_port\x18\x03 \x01(\r\x12\x16\n\x0espectator_port\x18\x04 \x01(\r\x12\x1d\n\x15spectator_server_name\x18\x05 \x01(\t\x12\x13\n\x0bserver_name\x18\x06 \x01(\t\x12\x0f\n\x07steamid\x18\x07 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x08 \x01(\r\x12\x0f\n\x07gamedir\x18\t \x01(\t\x12\x0b\n\x03map\x18\n \x01(\t\x12\x18\n\x10game_description\x18\x0b \x01(\t\x12\x10\n\x08gametype\x18\x0c \x01(\t\x12\x13\n\x0bnum_players\x18\r \x01(\r\x12\x13\n\x0bmax_players\x18\x0e \x01(\r\x12\x10\n\x08num_bots\x18\x0f \x01(\r\x12\x10\n\x08password\x18\x10 \x01(\x08\x12\x0e\n\x06secure\x18\x11 \x01(\x08\x12\x11\n\tdedicated\x18\x12 \x01(\x08\x12\x0f\n\x07version\x18\x13 \x01(\t\x12\x11\n\tsdr_popid\x18\x14 \x01(\x07\x12\x1b\n\x13sdr_location_string\x18\x15 \x01(\t\"\x95\x01\n\x1e\x43MsgGameServerPlayersQueryData\x12\x37\n\x07players\x18\x01 \x03(\x0b\x32&.CMsgGameServerPlayersQueryData.Player\x1a:\n\x06Player\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\r\x12\x13\n\x0btime_played\x18\x03 \x01(\r\"v\n\x1c\x43MsgGameServerRulesQueryData\x12\x31\n\x05rules\x18\x01 \x03(\x0b\x32\".CMsgGameServerRulesQueryData.Rule\x1a#\n\x04Rule\x12\x0c\n\x04rule\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xc2\x01\n%CGameServers_GameServerQuery_Response\x12/\n\tping_data\x18\x01 \x01(\x0b\x32\x1c.CMsgGameServerPingQueryData\x12\x35\n\x0cplayers_data\x18\x02 \x01(\x0b\x32\x1f.CMsgGameServerPlayersQueryData\x12\x31\n\nrules_data\x18\x03 \x01(\x0b\x32\x1d.CMsgGameServerRulesQueryData\"\x99\x01\n/CGameServers_ReportServerPingReply_Notification\x12\x31\n\x0bserver_data\x18\x01 \x01(\x0b\x32\x1c.CMsgGameServerPingQueryData\x12\x0f\n\x07ping_ms\x18\x02 \x01(\r\x12\"\n\x1a\x63lient_sdr_location_string\x18\x03 \x01(\t\"*\n(GameServerClient_QueryServerData_Request\"\xc6\x01\n)GameServerClient_QueryServerData_Response\x12/\n\tping_data\x18\x01 \x01(\x0b\x32\x1c.CMsgGameServerPingQueryData\x12\x35\n\x0cplayers_data\x18\x02 \x01(\x0b\x32\x1f.CMsgGameServerPlayersQueryData\x12\x31\n\nrules_data\x18\x03 \x01(\x0b\x32\x1d.CMsgGameServerRulesQueryData2\x9f\x03\n\x0bGameServers\x12l\n\x15GetServerSteamIDsByIP\x12+.CGameServers_GetServerSteamIDsByIP_Request\x1a&.CGameServers_IPsWithSteamIDs_Response\x12l\n\x15GetServerIPsBySteamID\x12+.CGameServers_GetServerIPsBySteamID_Request\x1a&.CGameServers_IPsWithSteamIDs_Response\x12\\\n\rQueryByFakeIP\x12#.CGameServers_QueryByFakeIP_Request\x1a&.CGameServers_GameServerQuery_Response\x12V\n\x15ReportServerPingReply\x12\x30.CGameServers_ReportServerPingReply_Notification\x1a\x0b.NoResponse2\x82\x01\n\x10GameServerClient\x12h\n\x0fQueryServerData\x12).GameServerClient_QueryServerData_Request\x1a*.GameServerClient_QueryServerData_Response\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_gameservers_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _GAMESERVERCLIENT._options = None
  _GAMESERVERCLIENT._serialized_options = b'\300\265\030\002'
  _CGAMESERVERS_GETSERVERSTEAMIDSBYIP_REQUEST._serialized_start=95
  _CGAMESERVERS_GETSERVERSTEAMIDSBYIP_REQUEST._serialized_end=159
  _CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE._serialized_start=162
  _CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE._serialized_end=306
  _CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE_SERVER._serialized_start=267
  _CGAMESERVERS_IPSWITHSTEAMIDS_RESPONSE_SERVER._serialized_end=306
  _CGAMESERVERS_GETSERVERIPSBYSTEAMID_REQUEST._serialized_start=308
  _CGAMESERVERS_GETSERVERIPSBYSTEAMID_REQUEST._serialized_end=377
  _CGAMESERVERS_QUERYBYFAKEIP_REQUEST._serialized_start=380
  _CGAMESERVERS_QUERYBYFAKEIP_REQUEST._serialized_end=636
  _CGAMESERVERS_QUERYBYFAKEIP_REQUEST_EQUERYTYPE._serialized_start=553
  _CGAMESERVERS_QUERYBYFAKEIP_REQUEST_EQUERYTYPE._serialized_end=636
  _CMSGGAMESERVERPINGQUERYDATA._serialized_start=639
  _CMSGGAMESERVERPINGQUERYDATA._serialized_end=1103
  _CMSGGAMESERVERPLAYERSQUERYDATA._serialized_start=1106
  _CMSGGAMESERVERPLAYERSQUERYDATA._serialized_end=1255
  _CMSGGAMESERVERPLAYERSQUERYDATA_PLAYER._serialized_start=1197
  _CMSGGAMESERVERPLAYERSQUERYDATA_PLAYER._serialized_end=1255
  _CMSGGAMESERVERRULESQUERYDATA._serialized_start=1257
  _CMSGGAMESERVERRULESQUERYDATA._serialized_end=1375
  _CMSGGAMESERVERRULESQUERYDATA_RULE._serialized_start=1340
  _CMSGGAMESERVERRULESQUERYDATA_RULE._serialized_end=1375
  _CGAMESERVERS_GAMESERVERQUERY_RESPONSE._serialized_start=1378
  _CGAMESERVERS_GAMESERVERQUERY_RESPONSE._serialized_end=1572
  _CGAMESERVERS_REPORTSERVERPINGREPLY_NOTIFICATION._serialized_start=1575
  _CGAMESERVERS_REPORTSERVERPINGREPLY_NOTIFICATION._serialized_end=1728
  _GAMESERVERCLIENT_QUERYSERVERDATA_REQUEST._serialized_start=1730
  _GAMESERVERCLIENT_QUERYSERVERDATA_REQUEST._serialized_end=1772
  _GAMESERVERCLIENT_QUERYSERVERDATA_RESPONSE._serialized_start=1775
  _GAMESERVERCLIENT_QUERYSERVERDATA_RESPONSE._serialized_end=1973
  _GAMESERVERS._serialized_start=1976
  _GAMESERVERS._serialized_end=2391
  _GAMESERVERCLIENT._serialized_start=2394
  _GAMESERVERCLIENT._serialized_end=2524
_builder.BuildServices(DESCRIPTOR, 'steammessages_gameservers_pb2', globals())
# @@protoc_insertion_point(module_scope)
